<?php

/**
 * ReduxFramework Config File
 */
if (!class_exists('Redux')) {
    return;
}


// This is your option name where all the Redux data is stored.
$opt_name = "kepler_theme_options";


// If Redux is running as a plugin, this will remove the demo notice and links
add_action( 'redux/loaded', 'remove_demo' );

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version' => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type' => 'menu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true,
    // Show the sections below the admin menu item or not
    'menu_title' => esc_html__('Theme Options', 'kepler-wp'),
    'page_title' => esc_html__('Theme Options', 'kepler-wp'),
    'google_api_key' => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => true,
    // Use a asynchronous font on the front end or font string
    'admin_bar' => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    // Show the time the page took to load, etc
    'update_notice' => false,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => true,
    // Enable basic customizer support
    // OPTIONAL -> Give you extra features
    'page_priority' => 57,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => 'themes.php',
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => '',
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => '',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.
    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'system_info' => false,
    'hints' => array(
        'icon' => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color' => 'lightgray',
        'icon_size' => 'normal',
        'tip_style' => array(
            'color' => 'red',
            'shadow' => true,
            'rounded' => false,
            'style' => '',
        ),
        'tip_position' => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect' => array(
            'show' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'mouseover',
            ),
            'hide' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'click mouseleave',
            ),
        ),
    )
);

Redux::setArgs($opt_name, $args);

/*
 * ---> END ARGUMENTS
 */


/*
 * ---> START HELP TABS
 */

$tabs = array(
    array(
        'id' => 'redux-help-tab-1',
        'title' => esc_html__('Theme Information 1', 'kepler-wp'),
        'content' => esc_html__('This is the tab content, HTML is allowed.', 'kepler-wp')
    ),
    array(
        'id' => 'redux-help-tab-2',
        'title' => esc_html__('Theme Information 2', 'kepler-wp'),
        'content' => esc_html__('This is the tab content, HTML is allowed.', 'kepler-wp')
    )
);
Redux::setHelpTab($opt_name, $tabs);

// Set the help sidebar
$content = esc_html__('This is the sidebar content, HTML is allowed.', 'kepler-wp');
Redux::setHelpSidebar($opt_name, $content);


// -> START Basic Fields
Redux::setSection($opt_name, array(
    'icon' => 'el-icon-cogs',
    'title' => esc_html__('General', 'kepler-wp'),
    'subsection' => false,
    'fields' => array(
        array(
            'id' => 'kepler-smoothscroll-toggle',
            'type' => 'button_set',
            'title' => esc_html__('Smoothscoll enable', 'kepler-wp'),
            'desc' => esc_html__('Toggle On or Off', 'kepler-wp'),
            'options' => array(
                '1' => 'On',
                '2' => 'Off'
            ),
            'default' => '2'
        ),
        array(
            'id' => 'kepler-404-selection',
            'type' => 'select',
            'title' => esc_html__('404 Page Selection', 'kepler-wp'),
            'subtitle' => esc_html__('Can replace the page displayed when error 404 occurs', 'kepler-wp'),
            'desc' => esc_html__('Chose a page for 404 error', 'kepler-wp'),
            'options' => kepler_pages_list(),
            'default' => 'default',
        ),
        array(
            'id' => 'kepler-custom-css',
            'type' => 'textarea',
            'title' => esc_html__('Custom CSS', 'kepler-wp'),
            'subtitle' => esc_html__('Only CSS code allowed', 'kepler-wp'),
            'desc' => esc_html__('This field is CSS validated.', 'kepler-wp'),
            'validate' => 'css',
        ),
        array(
            'id' => 'kepler-boxed-switch',
            'type' => 'button_set',
            'title' => esc_html__('Boxed mode', 'kepler-wp'),
            'subtitle' => esc_html__('Enable or disable the boxed version', 'kepler-wp'),
            'desc' => esc_html__('More options regarding boxed mode will show after enabling this.', 'kepler-wp'),
            'options' => array(
                '1' => 'Enable',
                '2' => 'Disable'
            ),
            'default' => '2'
        ),
        array('id' => 'kepler-boxed-background',
            'type' => 'background',
            'required' => array('kepler-boxed-switch', 'equals', '1'),
            'title' => esc_html__('Boxed mode options', 'kepler-wp'),
            'desc' => esc_html__('Select a color or image for the background', 'kepler-wp'),
            'transparent' => false,
            'preview_media' => true,
            'default' => array(
                'background-repeat' => 'repeat',
                'background-position' => 'center center'
            )),
    )
));

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-home',
    'title' => esc_html__('Header', 'kepler-wp'),
    'subsection' => false,
    'fields' => array(
        array(
            'id' => 'kepler-header-stickyheader-toggle',
            'type' => 'button_set',
            'title' => esc_html__('Sticky Header', 'kepler-wp'),
            'subtitle' => esc_html__('Enable or disable the sticky header', 'kepler-wp'),
            'desc' => esc_html__('Toggle On or Off', 'kepler-wp'),
            'options' => array(
                '1' => 'On',
                '2' => 'Off'
            ),
            'default' => '1'
        ),
        array(
            'id' => 'kepler-header-logo',
            'type' => 'media',
            'url' => true,
            'title' => esc_html__('Header Logo Selection', 'kepler-wp'),
            'desc' => esc_html__('Upload a new logo image', 'kepler-wp'),
            'subtitle' => esc_html__('Replace or remove the existing logo', 'kepler-wp'),
            'default' => array(
                'url' => get_template_directory_uri() . '/assets/images/logo.png')
        ),
        array(
            'id' => 'kepler-header-bg',
            'type' => 'media',
            'url' => true,
            'title' => esc_html__('Page header background', 'kepler-wp'),
            'desc' => esc_html__('Upload a new background image', 'kepler-wp'),
            'subtitle' => esc_html__('Replace or remove the existing image', 'kepler-wp'),
            'default' => array(
                'url' => get_template_directory_uri() . '/assets/images/page-header-default.jpg')
        ),
        array(
            'id' => 'kepler-header-menu-offset',
            'type' => 'slider',
            'title' => esc_html__( 'Header Menu Offset', 'kepler-wp' ),
            'subtitle' => esc_html__( 'Allows you to adjust menu position. It is needed when you want to adjust the menu position to the menu logo.', 'kepler-wp' ),
            "default" => 0,
            "min" => 0,
            "step" => 1,
            "max" => 500,
            'display_value' => 'text'
        ),
        array(
            'id' => 'kepler-footer-top-switch',
            'type' => 'button_set',
            'title' => esc_html__('Header widget area', 'kepler-wp'),
            'subtitle' => esc_html__('Enable or disable header widget area', 'kepler-wp'),
            'desc' => esc_html__('Enable or disable header widget area', 'kepler-wp'),
            'options' => array(
                '1' => 'Enable',
                '2' => 'Disable'
            ),
            'default' => '1'
        ),
        array(
            'id' => 'kepler-footer-top-layout',
            'type' => 'image_select',
            'required' => array('kepler-footer-top-switch', 'equals', '1'),
            'title' => esc_html__('Header widget area layout', 'kepler-wp'),
            'subtitle' => esc_html__('Select the number of widgetable areas', 'kepler-wp'),
            'options' => array(
                '1' => array(
                    'alt' => '1 Area',
                    'title' => '1',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l1.png'
                ),
                '2' => array(
                    'alt' => '2 Areas',
                    'title' => '2',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l2.png'
                ),
                '3' => array(
                    'alt' => '3 Areas',
                    'title' => '3',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l3.png'
                ),
                '4' => array(
                    'alt' => '4 Areas',
                    'title' => '4',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l4.png'
                )
            ),
            'default' => '2'
        )
    )
));
Redux::setSection($opt_name, array(
    'icon' => 'el-icon-credit-card',
    'title' => esc_html__('Footer', 'kepler-wp'),
    'subsection' => false,
    'fields' => array(
        array(
            'id' => 'kepler-footer-middle-switch',
            'type' => 'button_set',
            'title' => esc_html__('Footer widget area', 'kepler-wp'),
            'subtitle' => esc_html__('Enable or disable footer widge area', 'kepler-wp'),
            'desc' => esc_html__('Enable or disable footer widget area', 'kepler-wp'),
            'options' => array(
                '1' => 'Enable',
                '2' => 'Disable'
            ),
            'default' => '1'
        ),
        array(
            'id' => 'kepler-footer-middle-layout',
            'type' => 'image_select',
            'required' => array('kepler-footer-middle-switch', 'equals', '1'),
            'title' => esc_html__('Footer widget area Layout', 'kepler-wp'),
            'subtitle' => esc_html__('Select the number of widgetable areas', 'kepler-wp'),
            'options' => array(
                '1' => array(
                    'alt' => '1 Area',
                    'title' => '1',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l1.png'
                ),
                '2' => array(
                    'alt' => '2 Areas',
                    'title' => '2',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l2.png'
                ),
                '3' => array(
                    'alt' => '3 Areas',
                    'title' => '3',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l3.png'
                ),
                '4' => array(
                    'alt' => '4 Areas',
                    'title' => '4',
                    'img' => get_template_directory_uri() . '/framework/admin/images/l4.png'
                )
            ),
            'default' => '2'
        )
    )
));

Redux::setSection($opt_name, array(
    'icon' => 'el-icon-list',
    'title' => esc_html__('Color Schemes', 'kepler-wp'),
    'subsection' => false,
    'fields' => array(
        array(
            'id' => 'kepler-accent-colors-enable',
            'type' => 'button_set',
            'title' => esc_html__('Color scheme', 'kepler-wp'),
            'subtitle' => esc_html__('Enable or disable custom color scheme', 'kepler-wp'),
            'desc' => esc_html__('If it is disabled, then the default color scheme will be used.', 'kepler-wp'),
            'options' => array(
                '1' => 'Enable',
                '2' => 'Disable'
            ),
            'default' => '2'
        ),
        array(
            'id' => 'kepler-color-scheme-accent',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Borders and backgrounds color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a color for theme borders and backgrounds', 'kepler-wp'),
            'default' => '#000',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-scheme-accent1',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Components font color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a color for theme components font color', 'kepler-wp'),
            'default' => '#000',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-scheme-accent2',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Secondary color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a color for theme secondary color', 'kepler-wp'),
            'default' => '#a5a5a5',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-body-font',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Body font color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a font color', 'kepler-wp'),
            'default' => '#000',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-headings-font',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Headings font color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a font color', 'kepler-wp'),
            'default' => '#000',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-scheme-menu',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Menu font color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a font color', 'kepler-wp'),
            'default' => '#fff',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-scheme-menu-alt',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Menu font hover color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a font color', 'kepler-wp'),
            'default' => '#8b8b8b',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-hover-menu',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Dropdown and megamenu hover font color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a font color', 'kepler-wp'),
            'default' => '#000',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-scheme-sticky',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Sticky menu background color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a background color', 'kepler-wp'),
            'default' => '#000',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-scheme-submenu',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Sumbenus and megamenus background color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a background color', 'kepler-wp'),
            'default' => '#fff',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-scheme-submenu-font',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Sumbenus and megamenus font color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a background color', 'kepler-wp'),
            'default' => '#000',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-footer-top-background',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Header widget background color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a header top background color', 'kepler-wp'),
            'default' => '',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-footer-top-font',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Header widget area font color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a header top font color', 'kepler-wp'),
            'default' => '#a5a5a5',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-footer-background',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Footer background color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a footer background color', 'kepler-wp'),
            'default' => '#101112',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-footer-font',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Footer font color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a footer font color', 'kepler-wp'),
            'default' => '#a5a5a5',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-color-android-theme',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Android theme color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a color', 'kepler-wp'),
            'default' => '#000',
            'transparent' => false,
            'validate' => 'color',
        ),
        array(
            'id' => 'kepler-ms-color',
            'type' => 'color',
            'required' => array('kepler-accent-colors-enable', 'equals', '1'),
            'title' => esc_html__('Mstile theme color', 'kepler-wp'),
            'subtitle' => esc_html__('Pick a color', 'kepler-wp'),
            'default' => '#000',
            'transparent' => false,
            'validate' => 'color',
        )
    )
));

/*
 * <--- END SECTIONS
 */

/**
 * This is a test function that will let you see when the compiler hook occurs.
 * It only runs if a field    set with compiler=>true is changed.
 * */
function compiler_action($options, $css, $changed_values) {
    echo "<pre>";
    print_r($changed_values); // Values that have changed since the last save
    echo "</pre>";
}

/**
 * Custom function for the callback validation referenced above
 * */
if (!function_exists('redux_validate_callback_function')) {

    function redux_validate_callback_function($field, $value, $existing_value) {
        $error = false;
        $warning = false;

        //do your validation
        if ($value == 1) {
            $error = true;
            $value = $existing_value;
        } elseif ($value == 2) {
            $warning = true;
            $value = $existing_value;
        }

        $return['value'] = $value;

        if ($error == true) {
            $return['error'] = $field;
            $field['msg'] = 'your custom error message';
        }

        if ($warning == true) {
            $return['warning'] = $field;
            $field['msg'] = 'your custom warning message';
        }

        return $return;
    }

}

/**
 * Custom function for the callback referenced above
 */
if (!function_exists('redux_my_custom_field')) {

    function redux_my_custom_field($field, $value) {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }

}

/**
 * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
 * so you must use get_template_directory_uri() if you want to use any of the built in icons
 * */
function dynamic_section($sections) {
    //$sections = array();
    $sections[] = array(
        'title' => esc_html__('Section via hook', 'kepler-wp'),
        'desc' => esc_html__('This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.', 'kepler-wp'),
        'icon' => 'el el-paper-clip',
        // Leave this as a blank section, no options just some intro text set above.
        'fields' => array()
    );

    return $sections;
}

/**
 * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
 * */
function change_arguments($args) {
    //$args['dev_mode'] = true;

    return $args;
}

/**
 * Filter hook for filtering the default value of any given field. Very useful in development mode.
 * */
function change_defaults($defaults) {
    $defaults['str_replace'] = 'Testing filter hook!';

    return $defaults;
}

// Remove the demo link and the notice of integrated demo from the redux-framework plugin
function remove_demo() {

    // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
    if (class_exists('ReduxFrameworkPlugin')) {
        remove_filter('plugin_row_meta', array(
            ReduxFrameworkPlugin::instance(),
            'plugin_metalinks'
                ), null, 2);

        // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
        remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
    }
}

// Adds the custom CSS and the custom color schemes 
add_action('wp_head', 'kepler_theme_options_styles');

function kepler_theme_options_styles() {
    if (!is_admin()) {
        global $kepler_theme_options;

        echo '<style type="text/css">' . "\n";

        if (is_admin_bar_showing()) {
            echo '#header.stuck {padding-top: 40px;} #custom-search-form #s {margin: 75px auto;} #custom-search-submit {top: 80px;}';
        }
        
        $kepler_header_padding = 0;

        if( isset( $kepler_theme_options['kepler-header-menu-padding'] ) ){
            $kepler_header_padding = $kepler_theme_options['kepler-header-menu-padding'];
        }

        if( $kepler_header_padding != 0 ){
            echo '@media (min-width: 1025px) { 
                #header-wrap { padding-top: ' . absint( $kepler_header_padding ) . 'px; } 
                }';
        }

        $kepler_header_offset = 0;

        if( isset( $kepler_theme_options['kepler-header-menu-offset'] ) ){
            $kepler_header_offset = $kepler_theme_options['kepler-header-menu-offset'];
        }

        if( $kepler_header_offset > 0 ){
            echo '.sf-menu { margin-top: ' . absint( $kepler_header_offset ) . 'px; }';
        }

        $kepler_accent_colors_enable = 0;

        if (isset($kepler_theme_options['kepler-accent-colors-enable'])) {
            $kepler_accent_colors_enable = $kepler_theme_options['kepler-accent-colors-enable'];
        }
        if ($kepler_accent_colors_enable == 1) {

            $body_font = "#000";
            if (isset($kepler_theme_options['kepler-color-body-font'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-body-font'])) {
                    $body_font = $kepler_theme_options['kepler-color-body-font'];
                }
            }

            if ($body_font != "#000") {
                echo 'body { color: ' . esc_attr($body_font) . '; }';
            }

            $headings_font = "#000";
            if (isset($kepler_theme_options['kepler-color-headings-font'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-headings-font'])) {
                    $headings_font = $kepler_theme_options['kepler-color-headings-font'];
                }
            }

            if ($headings_font != "#000") {
                echo 'h1, 
                    h2, 
                    h3, 
                    h4, 
                    h5, 
                    h6 { color: ' . esc_attr($headings_font) . '; }';
            }

            $color_accent = "#000";
            if (isset($kepler_theme_options['kepler-color-scheme-accent'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-scheme-accent'])) {
                    $color_accent = $kepler_theme_options['kepler-color-scheme-accent'];
                }
            }
            
            if ($color_accent != "#000") {
                
                echo '.bx-wrapper .bx-pager.bx-default-pager a:hover,
                    .bx-wrapper .bx-pager.bx-default-pager a.active,
                    .text-highlight,
                    button,
                    input[type="reset"],
                    input[type="submit"],
                    input[type="button"],
                    #page-header,
                    #back-to-top,
                    .btn,
                    .horizontal-process-builder li:hover span,
                    .progress-bar .progress-bar-outer,
                    .team-member:hover .team-member-details,
                    .custom-color .horizontal-process-builder li h5,
                    .sticky-post,
                    .widget_tag_cloud a,
                    #wp-calendar tbody a
                    { background-color: ' . esc_attr($color_accent) . '; }';
                
                echo '.theme-accordion .vc_active .vc_tta-panel-title a,
                    .theme-accordion .vc_tta-panel-title a:hover,
                    .theme-tabs .vc_tta-tab a,
                    .btn-white:after
                    { background-color: ' . esc_attr($color_accent) . ' !important; }';

                echo 'button,
                    input[type="reset"],
                    input[type="submit"],
                    input[type="button"],
                    .alert,
                    .alert.info,
                    .btn,
                    .btn-white,
                    .features-list .features-list-menu li a,
                    .bx-wrapper .bx-pager.bx-default-pager a,
                    .pagination .page-numbers a:hover,
                    .pagination .page-numbers.current a,
                    .widget_tag_cloud a
                    { border-color: ' . esc_attr($color_accent) . '; }';

              echo '.theme-accordion .vc_active .vc_tta-panel-title a,
                    .theme-accordion .vc_tta-panel-title a:hover
                    { border-color: ' . esc_attr($color_accent) . ' !important; }';

              echo '.sf-arrows .sf-with-ul:after
                    { border-top-color: ' . esc_attr($color_accent) . '; }';

                echo '.sf-arrows ul .sf-with-ul:after
                    { border-left-color: ' . esc_attr($color_accent) . '; }';

                echo '.headline:after,
                    .headline-center:after,
                    .pricing-table-header h4:after
                    { border-bottom-color: ' . esc_attr($color_accent) . ' !important; }';
                
                echo '.btn-white {background-color: transparent;}';

            }
            
            $color_accent1 = "#000";
            if (isset($kepler_theme_options['kepler-color-scheme-accent1'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-scheme-accent1'])) {
                    $color_accent1 = $kepler_theme_options['kepler-color-scheme-accent1'];
                }
            }
            
            if ($color_accent1 != "#000") {
                
                echo 'a, 
                    a:visited,
                    input[type="text"],
                    input[type="password"],
                    input[type="date"],
                    input[type="datetime"],
                    input[type="datetime-local"],
                    input[type="month"],
                    input[type="week"],
                    input[type="email"],
                    input[type="number"],
                    input[type="search"],
                    input[type="tel"],
                    input[type="time"],
                    input[type="url"],
                    input[type="color"],
                    textarea,
                    select,
                    button:hover,
                    input[type="reset"]:hover,
                    input[type="submit"]:hover,
                    input[type="button"]:hover,
                    .alert,
                    .alert.info,
                    .features-list .features-list-menu li a:hover,
                    .features-list .features-list-menu li.active a,
                    .icon-box-4:hover, 
                    .icon-box-4:hover a,
                    .horizontal-process-builder li h5,
                    a.social-icon,
                    .custom-color .btn:hover,
                    .custom-color .horizontal-process-builder li:hover h5 span,
                    .format-quote .post-content blockquote,
                    .format-link .post-content a,
                    .pagination .page-numbers a:hover,
                    .pagination .page-numbers.current a,
                    .pagination .page-numbers.dots:hover,
                    .comment-form input[type="submit"]:hover,
                    .widget_tag_cloud a:hover
                    { color: ' . esc_attr($color_accent1) . '; }';

                echo '.theme-accordion .vc_tta-panel-title a,
                    .theme-tabs .vc_tta-tab.vc_active a,
                    .theme-tabs .vc_tta-tab a:hover,
                    .theme-tabs .vc_tta-tab a:focus,
                    .btn:hover,
                    .btn-white
                    { color: ' . esc_attr($color_accent1) . ' !important; }';

            }
            
            $color_accent2 = "#a5a5a5";
            if (isset($kepler_theme_options['kepler-color-scheme-accent2'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-scheme-accent2'])) {
                    $color_accent2 = $kepler_theme_options['kepler-color-scheme-accent2'];
                }
            }
            
            if ($color_accent2 != "#a5a5a5") {
                
                echo '.sf-menu > li.current > a,
                    .sf-menu li.sfHover > a,
                    .sf-menu a:hover,
                    .sf-menu > li.current > a,
                    .sf-menu li.sfHover > a,
                    .sf-menu a:hover,
                    .sf-menu > li.current-menu-parent > a,
                    #page-header,
                    .testimonial h6,
                    .comment-author a,
                    .comment-meta a,
                    .pingback .edit-link a,
                    .comment-list .reply a
                    { color: ' . esc_attr($color_accent2) . '; }';

            }
            
            $menu_font = "#fff";

            if (isset($kepler_theme_options['kepler-color-scheme-menu'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-scheme-menu'])) {
                    $menu_font = $kepler_theme_options['kepler-color-scheme-menu'];
                }
            }

            if ($menu_font != "#fff" && $menu_font != "#ffffff") {
                echo '.sf-menu > li > a,
                    .sf-menu > li.dropdown > a
                    { color: ' . esc_attr($menu_font) . '; }';
            }
            
            $menu_alt = "#8b8b8b";

            if (isset($kepler_theme_options['kepler-color-scheme-menu-alt'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-scheme-menu-alt'])) {
                    $menu_alt = $kepler_theme_options['kepler-color-scheme-menu-alt'];
                }
            }

            if ($menu_alt != "#8b8b8b") {
                echo '.sf-menu > li > a,
                    .sf-menu > li.dropdown > a
                    { color: ' . esc_attr($menu_alt) . '; }';
            }

            $menu_hover = "#000";

            if (isset($kepler_theme_options['kepler-color-hover-menu'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-hover-menu'])) {
                    $menu_hover = $kepler_theme_options['kepler-color-hover-menu'];
                }
            }

            if ($menu_hover != "#000") {
                echo '.sf-menu li.sfHover li a:hover, 
                    .sf-menu li li.sfHover > a, 
                    .sf-menu li li.sfHover > a
                    { color: ' . esc_attr($menu_hover) . '; }';
            }
            
            $sticky_bg = "#000";

            if (isset($kepler_theme_options['kepler-color-scheme-sticky'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-scheme-sticky'])) {
                    $sticky_bg = $kepler_theme_options['kepler-color-scheme-sticky'];
                }
            }

            if ($sticky_bg != "#000") {
                echo '#header.stuck
                    { background-color: ' . esc_attr($sticky_bg) . '; }';
            }
            
            $submenu_bg = "#fff";

            if (isset($kepler_theme_options['kepler-color-scheme-submenu'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-scheme-submenu'])) {
                    $submenu_bg = $kepler_theme_options['kepler-color-scheme-submenu'];
                }
            }

            if ($submenu_bg != "#fff") {
                echo '.sf-menu li.dropdown ul,.sf-mega
                    { background-color: ' . esc_attr($submenu_bg) . '; }';
            }
            
            $submenu_font = "#000";

            if (isset($kepler_theme_options['kepler-color-scheme-submenu-font'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-scheme-submenu-font'])) {
                    $submenu_font = $kepler_theme_options['kepler-color-scheme-submenu-font'];
                }
            }

            if ($submenu_font != "#000") {
                echo '.sf-menu a
                    { color: ' . esc_attr($submenu_font) . '; }';
            }
            
             $footer_top_font = "#a5a5a5";

            if (isset($kepler_theme_options['kepler-color-footer-top-font'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-footer-top-font'])) {
                    $footer_top_font = $kepler_theme_options['kepler-color-footer-top-font'];
                }
            }

            if ($footer_top_font != "#a5a5a5") {
                echo '#header-top,
                    #header-top a,
                        #header-top h1, 
                        #header-top h2, 
                        #header-top h3, 
                        #header-top h4, 
                        #header-top h5, 
                        #header-top h6 
                        { color: ' . esc_attr($footer_top_font) . '; }';
            }

            $footer_top_background = '';

            if (isset($kepler_theme_options['kepler-color-footer-top-background'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-footer-top-background'])) {
                    $footer_top_background = $kepler_theme_options['kepler-color-footer-top-background'];
                }
            }

            if ($footer_top_background != '') {
                echo '#header-top { background-color: ' . esc_attr($footer_top_background) . '; }';
            }

            $footer_font = "#a5a5a5";

            if (isset($kepler_theme_options['kepler-color-footer-font'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-footer-font'])) {
                    $footer_font = $kepler_theme_options['kepler-color-footer-font'];
                }
            }

            if ($footer_font != "#a5a5a5") {
                echo '#footer,
                    #footer a,
                    #footer h1, 
                        #footer h2, 
                        #footer h3, 
                        #footer h4, 
                        #footer h5, 
                        #footer h6,
                        #footer .textwidget a
                        { color: ' . esc_attr($footer_font) . '; }';
            }

            $footer_background = "#101112";

            if (isset($kepler_theme_options['kepler-color-footer-background'])) {
                if (preg_match('/(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i', $kepler_theme_options['kepler-color-footer-background'])) {
                    $footer_background = $kepler_theme_options['kepler-color-footer-background'];
                }
            }

            if ($footer_background != "#101112") {
                echo '#footer { background: none; background-color: ' . esc_attr($footer_background) . '; }';
            }
            
        }
        
        $kepler_boxed_color = $kepler_boxed_image = $kepler_boxed_repeat = $kepler_boxed_position = $kepler_boxed_size = $kepler_boxed_attachment = '';

        if (isset($kepler_theme_options['kepler-boxed-background']['background-color'])) {
            $kepler_boxed_color = $kepler_theme_options['kepler-boxed-background']['background-color'];
        }

        if (isset($kepler_theme_options['kepler-boxed-background']['background-image'])) {
            $kepler_boxed_image = $kepler_theme_options['kepler-boxed-background']['background-image'];
        }

        if (isset($kepler_theme_options['kepler-boxed-background']['background-repeat'])) {
            $kepler_boxed_repeat = $kepler_theme_options['kepler-boxed-background']['background-repeat'];
        }

        if (isset($kepler_theme_options['kepler-boxed-background']['background-position'])) {
            $kepler_boxed_position = $kepler_theme_options['kepler-boxed-background']['background-position'];
        }

        if (isset($kepler_theme_options['kepler-boxed-background']['background-size'])) {
            $kepler_boxed_size = $kepler_theme_options['kepler-boxed-background']['background-size'];
        }

        if (isset($kepler_theme_options['kepler-boxed-background']['background-attachment'])) {
            $kepler_boxed_attachment = $kepler_theme_options['kepler-boxed-background']['background-attachment'];
        }
        
        if ($kepler_boxed_color != null || $kepler_boxed_image != null) {
            echo ' body.boxed {';
            if ($kepler_boxed_color != null) {
                echo 'background-color: ' . esc_attr($kepler_boxed_color) . ';';
            }

            // Background image.
            if ($kepler_boxed_image != null) {
                echo 'background-image: url(' . esc_url($kepler_boxed_image) . ');';
            }

            // Background image options
            if ($kepler_boxed_repeat != null) {
                echo 'background-repeat: ' . esc_attr($kepler_boxed_repeat) . ';';
            }
            if ($kepler_boxed_position != null) {
                echo 'background-position: ' . esc_attr($kepler_boxed_position) . ';';
            }
            if ($kepler_boxed_size != null) {
                echo 'background-size: ' . esc_attr($kepler_boxed_size) . ';';
            }
            if ($kepler_boxed_attachment != null) {
                echo 'background-attachment: ' . esc_attr($kepler_boxed_attachment) . ';';
            }

            echo '}';
        }

        /* Theme options custom css related field */
        $kepler_custom_css = "";
        if (isset($kepler_theme_options['kepler-custom-css'])) {
            $kepler_custom_css = $kepler_theme_options['kepler-custom-css'];
        }
        if (trim($kepler_custom_css) != '') {
            print $kepler_custom_css;
        }

        echo '</style>' . "\n";
    }
}

function kepler_hex_to_rgba($color, $opacity = false) {

    $default = 'rgb(0,0,0)';

    //Return default if no color provided
    if (empty($color))
        return $default;

    //Sanitize $color if "#" is provided 
    if ($color[0] == '#') {
        $color = substr($color, 1);
    }

    //Check if color has 6 or 3 characters and get values
    if (strlen($color) == 6) {
        $hex = array($color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5]);
    } elseif (strlen($color) == 3) {
        $hex = array($color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2]);
    } else {
        return $default;
    }

    //Convert hexadec to rgb
    $rgb = array_map('hexdec', $hex);

    //Check if opacity is set(rgba or rgb)
    if ($opacity) {
        if (abs($opacity) > 1)
            $opacity = 1.0;
        $output = 'rgba(' . implode(",", $rgb) . ',' . $opacity . ')';
    } else {
        $output = 'rgb(' . implode(",", $rgb) . ')';
    }

    //Return rgb(a) color string
    return $output;
}