<?php

if (!defined('ABSPATH')) {
    exit();
}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Alert Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_alert_elements_func($atts, $content = null) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_alert_type' => 'info',
    'css' => '' ), $atts));

    $content = esc_html($content);

    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

    // Determines the type of alert
    if ($kepler_alert_type == "info") {
        return "<div class='alert info {$css_class}'><i class='ifc-christmas_star'></i>{$content}</div>";
    } elseif ($kepler_alert_type == "success") {
        return "<div class='alert success {$css_class}'><i class='ifc-checkmark'></i>{$content}</div>";
    } elseif ($kepler_alert_type == "warning") {
        return "<div class='alert warning {$css_class}'><i class='ifc-warning_shield'></i>{$content}</div>";
    } elseif ($kepler_alert_type == "error") {
        return "<div class='alert error {$css_class}'><i class='ifc-error'></i>{$content}</div>";
    } else {
        return "<div class='alert {$css_class}'><i class='ifc-info'></i>{$content}</div>";
    }
}

add_shortcode('kepler_alert_elements', 'kepler_alert_elements_func');

add_action('init', 'kepler_integrate_vc_alert_elements');

// integrates the custom element in the visual composer
function kepler_integrate_vc_alert_elements() {
    vc_map(
            array(
                "name" => esc_html__("Message box", 'kepler-wp'),
                "base" => "kepler_alert_elements",
                "icon" => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                "category" => esc_html__('Kepler Elements', 'kepler-wp'),
                "params" => array(
                    array(
                        'type' => 'dropdown',
                        'holder' => 'div',
                        'heading' => esc_html__('Message Type', 'kepler-wp'),
                        'param_name' => 'kepler_alert_type',
                        'value' => array(
                            esc_html__('Info', 'kepler-wp') => 'info',
                            esc_html__('Default', 'kepler-wp') => 'default',
                            esc_html__('Success', 'kepler-wp') => 'success',
                            esc_html__('Warning', 'kepler-wp') => 'warning',
                            esc_html__('Error', 'kepler-wp') => 'error',
                        ),
                        'description' => esc_html__('Specify', 'kepler-wp')
                    ),
                    array(
                        "type" => "textfield",
                        "heading" => esc_html__("Message", 'kepler-wp'),
                        "param_name" => "content",
                        "description" => esc_html__("Specify the content of the message", 'kepler-wp')
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}

class WPBakeryShortCode_kepler_alert_elements extends WPBakeryShortCode {
    
}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Animations Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_animations_container_func($atts, $content = null) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_animate_type' => 'bounce',
    'kepler_animate_delay' => '0',
    'kepler_animate_speed' => '1000',
    'kepler_animate_offset' => '90',
    'css' => '' ), $atts));

    $content = wpb_js_remove_wpautop($content, false);
    $kepler_animate_type = esc_attr($kepler_animate_type);
    $kepler_animate_delay = esc_attr($kepler_animate_delay);
    $kepler_animate_speed = esc_attr($kepler_animate_speed);
    $kepler_animate_offset = esc_attr($kepler_animate_offset);
    if ($kepler_animate_offset > 100) {
        $kepler_animate_offset = 90;
    }

    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

    return "<div class='animate {$css_class}' data-animation='{$kepler_animate_type}' data-animation-delay='{$kepler_animate_delay}' data-animation-speed='{$kepler_animate_speed}' data-animation-offset='{$kepler_animate_offset}%'>
                            {$content}
            </div>";
}

add_shortcode('kepler_animations_container', 'kepler_animations_container_func');
add_action('init', 'kepler_integrate_vc_animations_container_component');

// integrates the custom element in the visual composer
function kepler_integrate_vc_animations_container_component() {
    vc_map(array(
        "name" => esc_html__("Animations Container", 'kepler-wp'),
        "base" => "kepler_animations_container",
        "category" => esc_html__('Kepler Elements', 'kepler-wp'),
        'as_parent' => array('except' => 'kepler_animations_container'),
        "content_element" => true,
        "icon" => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
        "show_settings_on_create" => true,
        "params" => array(
            array(
                'type' => 'dropdown',
                'holder' => 'div',
                'heading' => esc_html__('Animation Type', 'kepler-wp'),
                'param_name' => 'kepler_animate_type',
                'value' => array(
                    esc_html__('bounce', 'kepler-wp') => 'bounce',
                    esc_html__('flash', 'kepler-wp') => 'flash',
                    esc_html__('pulse', 'kepler-wp') => 'pulse',
                    esc_html__('rubberBand', 'kepler-wp') => 'rubberBand',
                    esc_html__('shake', 'kepler-wp') => 'shake',
                    esc_html__('swing', 'kepler-wp') => 'swing',
                    esc_html__('tada', 'kepler-wp') => 'tada',
                    esc_html__('wobble', 'kepler-wp') => 'wobble',
                    esc_html__('bounceIn', 'kepler-wp') => 'bounceIn',
                    esc_html__('bounceInDown', 'kepler-wp') => 'bounceInDown',
                    esc_html__('bounceInLeft', 'kepler-wp') => 'bounceInLeft',
                    esc_html__('bounceInRight', 'kepler-wp') => 'bounceInRight',
                    esc_html__('bounceInUp', 'kepler-wp') => 'bounceInUp',
                    esc_html__('bounceOut', 'kepler-wp') => 'bounceOut',
                    esc_html__('bounceOutDown', 'kepler-wp') => 'bounceOutDown',
                    esc_html__('bounceOutLeft', 'kepler-wp') => 'bounceOutLeft',
                    esc_html__('bounceOutRight', 'kepler-wp') => 'bounceOutRight',
                    esc_html__('bounceOutUp', 'kepler-wp') => 'bounceOutUp',
                    esc_html__('fadeIn', 'kepler-wp') => 'fadeIn',
                    esc_html__('fadeInDown', 'kepler-wp') => 'fadeInDown',
                    esc_html__('fadeInDownBig', 'kepler-wp') => 'fadeInDownBig',
                    esc_html__('fadeInLeft', 'kepler-wp') => 'fadeInLeft',
                    esc_html__('fadeInLeftBig', 'kepler-wp') => 'fadeInLeftBig',
                    esc_html__('fadeInRight', 'kepler-wp') => 'fadeInRight',
                    esc_html__('fadeInRightBig', 'kepler-wp') => 'fadeInRightBig',
                    esc_html__('fadeInUp', 'kepler-wp') => 'fadeInUp',
                    esc_html__('fadeInUpBig', 'kepler-wp') => 'fadeInUpBig',
                    esc_html__('fadeOut', 'kepler-wp') => 'fadeOut',
                    esc_html__('fadeOutDown', 'kepler-wp') => 'fadeOutDown',
                    esc_html__('fadeOutDownBig', 'kepler-wp') => 'fadeOutDownBig',
                    esc_html__('fadeOutLeft', 'kepler-wp') => 'fadeOutLeft',
                    esc_html__('fadeOutLeftBig', 'kepler-wp') => 'fadeOutLeftBig',
                    esc_html__('fadeOutRight', 'kepler-wp') => 'fadeOutRight',
                    esc_html__('fadeOutRightBig', 'kepler-wp') => 'fadeOutRightBig',
                    esc_html__('fadeOutUp', 'kepler-wp') => 'fadeOutUp',
                    esc_html__('fadeOutUpBig', 'kepler-wp') => 'fadeOutUpBig',
                    esc_html__('flip', 'kepler-wp') => 'flip',
                    esc_html__('flipInX', 'kepler-wp') => 'flipInX',
                    esc_html__('flipInY', 'kepler-wp') => 'flipInY',
                    esc_html__('flipOutX', 'kepler-wp') => 'flipOutX',
                    esc_html__('flipOutY', 'kepler-wp') => 'flipOutY',
                    esc_html__('lightSpeedIn', 'kepler-wp') => 'lightSpeedIn',
                    esc_html__('lightSpeedOut', 'kepler-wp') => 'lightSpeedOut',
                    esc_html__('rotateIn', 'kepler-wp') => 'rotateIn',
                    esc_html__('rotateInDownLeft', 'kepler-wp') => 'rotateInDownLeft',
                    esc_html__('rotateInDownRight', 'kepler-wp') => 'rotateInDownRight',
                    esc_html__('rotateInUpLeft', 'kepler-wp') => 'rotateInUpLeft',
                    esc_html__('rotateInUpRight', 'kepler-wp') => 'rotateInUpRight',
                    esc_html__('rotateOut', 'kepler-wp') => 'rotateOut',
                    esc_html__('rotateOutDownLeft', 'kepler-wp') => 'rotateOutDownLeft',
                    esc_html__('rotateOutDownRight', 'kepler-wp') => 'rotateOutDownRight',
                    esc_html__('rotateOutUpLeft', 'kepler-wp') => 'rotateOutUpLeft',
                    esc_html__('rotateOutUpRight', 'kepler-wp') => 'rotateOutUpRight',
                    esc_html__('hinge', 'kepler-wp') => 'hinge',
                    esc_html__('rollIn', 'kepler-wp') => 'rollIn',
                    esc_html__('rollOut', 'kepler-wp') => 'rollOut',
                    esc_html__('zoomIn', 'kepler-wp') => 'zoomIn',
                    esc_html__('zoomInDown', 'kepler-wp') => 'zoomInDown',
                    esc_html__('zoomInLeft', 'kepler-wp') => 'zoomInLeft',
                    esc_html__('zoomInRight', 'kepler-wp') => 'zoomInRight',
                    esc_html__('zoomInUp', 'kepler-wp') => 'zoomInUp',
                    esc_html__('zoomOut', 'kepler-wp') => 'zoomOut',
                    esc_html__('zoomOutDown', 'kepler-wp') => 'zoomOutDown',
                    esc_html__('zoomOutLeft', 'kepler-wp') => 'zoomOutLeft',
                    esc_html__('zoomOutRight', 'kepler-wp') => 'zoomOutRight',
                    esc_html__('zoomOutUp', 'kepler-wp') => 'zoomOutUp'
                ),
                'description' => esc_html__('Specify', 'kepler-wp')
            ),
            array(
                "type" => "textfield",
                "heading" => esc_html__("Animation Delay", 'kepler-wp'),
                "param_name" => "kepler_animate_delay",
                "value" => '0',
                "description" => esc_html__("Specify the delay amount", 'kepler-wp')
            ),
            array(
                "type" => "textfield",
                "heading" => esc_html__("Animation Speed", 'kepler-wp'),
                "param_name" => "kepler_animate_speed",
                "value" => '1000',
                "description" => esc_html__("Specify the delay amount(in milliseconds, 1000 milliseconds = 1 second)", 'kepler-wp')
            ),
            array(
                "type" => "textfield",
                "heading" => esc_html__("Animation Offset", 'kepler-wp'),
                "param_name" => "kepler_animate_offset",
                "value" => '90',
                "description" => esc_html__("Specify the Offset amount (in percentage from 0 to 100)", 'kepler-wp')
            ),
            array(
                'type' => 'css_editor',
                'heading' => esc_html__('Css', 'kepler-wp'),
                'param_name' => 'css',
                'group' => esc_html__('Design options', 'kepler-wp'),
            )
        ),
        'js_view' => 'VcColumnView'));
}

if (class_exists('WPBakeryShortCodesContainer')) {

    class WPBakeryShortCode_kepler_animations_container extends WPBakeryShortCodesContainer {
        
    }

}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Button Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_button_formats_func($atts) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_link' => '',
    'kepler_icon' => '',
    'kepler_large' => '',
    'kepler_color' => '',
    'kepler_align' => '',
    'css' => '' ), $atts));

    $kepler_icon = esc_attr($kepler_icon);
    $link_details = vc_build_link($kepler_link);
    $kepler_color = esc_attr($kepler_color);

    $large = $center_before = $center_after = $button_icon = $newtab = '';

    if (trim($kepler_icon) != "") {
        $button_icon = "<i class='{$kepler_icon}'></i>";
    }

    if ($kepler_large == "large") {
        $large = " btn-large";
    }

    if ($kepler_align == "center") {
        $center_before = "<div class='text-center'>";
        $center_after = "</div>";
    } else if ($kepler_align == "right") {
        $center_before = "<div class='text-right'>";
        $center_after = "</div>";
    }

    $link_details['target'] = esc_attr($link_details['target']);
    $link_details['url'] = esc_url($link_details['url']);
    $link_details['title'] = esc_html($link_details['title']);

    if ($link_details['target'] != '') {
        $newtab = "target='{$link_details['target']}'";
    }

    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

    return "{$center_before}<a class='btn{$large}{$kepler_color} {$css_class}' href='{$link_details['url']}' {$newtab}>{$button_icon}{$link_details['title']}</a>{$center_after}";
}

add_shortcode('kepler_button_formats', 'kepler_button_formats_func');
add_action('init', 'kepler_integrate_vc_button_formats');

// integrates the custom element in the visual composer
function kepler_integrate_vc_button_formats() {
    vc_map(
            array(
                'name' => esc_html__('Button(s)', 'kepler-wp'),
                'base' => 'kepler_button_formats',
                'category' => esc_html__('Kepler Elements', 'kepler-wp'),
                'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                'params' => array(
                    array(
                        'type' => 'vc_link',
                        'heading' => esc_html__('Link title &amp; URL', 'kepler-wp'),
                        'param_name' => 'kepler_link',
                        'description' => esc_html__('Specify the link pointing to another page', 'kepler-wp')
                    ),
                    array(
                        'type' => 'kepler_icomoon_icons_param',
                        'heading' => esc_html__('Select icon', 'kepler-wp'),
                        'param_name' => 'kepler_icon',
                        'description' => esc_html__('Select the icon you want', 'kepler-wp')
                    ),
                    array(
                        'type' => 'checkbox',
                        'heading' => esc_html__('Button Size', 'kepler-wp'),
                        'param_name' => 'kepler_large',
                        'value' => array(esc_html__('Large', 'kepler-wp') => 'large')
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Button Position', 'kepler-wp'),
                        'param_name' => 'kepler_align',
                        'value' => array(
                            esc_html__('Left', 'kepler-wp') => '',
                            esc_html__('Center', 'kepler-wp') => 'center',
                            esc_html__('Right', 'kepler-wp') => 'right'
                        )
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Button Color', 'kepler-wp'),
                        'param_name' => 'kepler_color',
                        'value' => array(
                            esc_html__('Default', 'kepler-wp') => '',
                            esc_html__('White', 'kepler-wp') => ' btn-white'
                        )
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}

class WPBakeryShortCode_kepler_button_formats extends WPBakeryShortCode {
    
}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Divider Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_dividers_func($atts) {

    $css = '';
    extract(shortcode_atts(array(
        'kepler_divider_type' => 'single-line',
        'css' => ''), $atts));

    $kepler_divider_type = sanitize_html_class($kepler_divider_type);
    
    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

    return "<div class='divider {$kepler_divider_type} {$css_class}'></div>";
}

add_shortcode('kepler_dividers', 'kepler_dividers_func');

add_action('init', 'kepler_integrate_vc_dividers');

// integrates the custom element in the visual composer
function kepler_integrate_vc_dividers() {
    vc_map(
            array(
                "name" => esc_html__("Divider", 'kepler-wp'),
                "base" => "kepler_dividers",
                "icon" => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                "category" => esc_html__('Kepler Elements', 'kepler-wp'),
                "params" => array(
                    array(
                        'type' => 'dropdown',
                        'holder' => 'div',
                        'heading' => esc_html__('Divider Type', 'kepler-wp'),
                        'param_name' => 'kepler_divider_type',
                        'value' => array(
                            esc_html__('Single Line', 'kepler-wp') => 'single-line',
                            esc_html__('Double Line', 'kepler-wp') => 'double-line',
                            esc_html__('Single Dotted', 'kepler-wp') => 'single-dotted',
                            esc_html__('Double Dotted', 'kepler-wp') => 'double-dotted'
                        ),
                        'description' => esc_html__('Specify', 'kepler-wp')
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}
class WPBakeryShortCode_kepler_dividers extends WPBakeryShortCode {
    
}
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       VC CUSTOM FEATURES SLIDER ELEMENTS
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_feature_element_func($atts, $content = null) { // New function parameter $content is added!
    extract(shortcode_atts(array(
    'kepler_title' => '' ), $atts));

    $content = wp_kses_post($content);
    $kepler_title = esc_html($kepler_title);
    
    return "{$kepler_title}kepler-separator{$content}kepler-separator";
}

add_shortcode('kepler_feature_element', 'kepler_feature_element_func');

function kepler_feature_slider_container_func($atts, $content = null) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_class' => '',
    'css' => '' ), $atts));

    $content = wpb_js_remove_wpautop($content, false);

    $kepler_class = esc_attr($kepler_class);
    $list = $tabs = '';
    $parts = explode('kepler-separator', $content);
    array_pop($parts);
    $i = 0;
    $j = 1;
    if (!empty($parts)) {
        foreach ($parts as $part) {
            if ($i == 0) {
                $list.="<li><a href='#content-tab-1-{$j}'><span>{$part}</span></a></li>";
                $i = 1;
            } else if ($i == 1) {
                $tabs.="<div class='tab-content' id='content-tab-1-{$j}'><p>{$part}</p></div>";
                $i = 0;
                $j++;
            }
        }
    }
    
    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

    return "<div class='features-list {$css_class}'><ul class='features-list-menu'>{$list}</ul><div class='tabs'>{$tabs}</div></div>";
}

add_shortcode('kepler_feature_slider_container', 'kepler_feature_slider_container_func');

add_action('init', 'kepler_integrate_vc_feature_slider_components');

// integrates the custom element in the visual composer
function kepler_integrate_vc_feature_slider_components() {
    vc_map(array(
        'name' => esc_html__('Feature Slider Container', 'kepler-wp'),
        'base' => 'kepler_feature_slider_container',
        'category' => esc_html__('Kepler Elements', 'kepler-wp'),
        'as_parent' => array('only' => 'kepler_feature_element'),
        'content_element' => true,
        "icon" => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
        'show_settings_on_create' => false,
        'params' => array(
            array(
                'type' => 'textfield',
                'holder' => 'div',
                'heading' => esc_html__('Extra Class', 'kepler-wp'),
                'param_name' => 'kepler_class',
                'description' => esc_html__('Specify an optional extra class', 'kepler-wp')
            ),
            array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
            ),
        'js_view' => 'VcColumnView'
    ));

    vc_map(
            array(
                'name' => esc_html__('Feature', 'kepler-wp'),
                'base' => 'kepler_feature_element',
                "icon" => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                'category' => esc_html__('Kepler Elements', 'kepler-wp'),
                'as_child' => array('only' => 'kepler_feature_slider_container'),
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'holder' => 'div',
                        'heading' => esc_html__('Title', 'kepler-wp'),
                        'param_name' => 'kepler_title',
                        'value' => '',
                        'description' => esc_html__('Specify the feature title', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textarea_html',
                        'heading' => esc_html__('Content', 'kepler-wp'),
                        'param_name' => 'content',
                        'description' => esc_html__('Specify the content of the feature', 'kepler-wp')
                    )
                )
            )
    );
}

if (class_exists('WPBakeryShortCodesContainer')) {

    class WPBakeryShortCode_kepler_feature_slider_container extends WPBakeryShortCodesContainer {
        
    }

}
if (class_exists('WPBakeryShortCode')) {

    class WPBakeryShortCode_kepler_feature_element extends WPBakeryShortCode {
        
    }

}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Google Map Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_gmaps_func($atts) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_zoom' => '16',
    'kepler_address' => '',
    'kepler_popup' => 'false',
    'kepler_height' => '635',
    'kepler_type' => 'ROADMAP',
    'kepler_caption' => '',
    'css' => '' ), $atts));

    // Numeric validation
    $kepler_zoom = absint($kepler_zoom);
    $kepler_address = esc_attr($kepler_address);
    $kepler_caption = esc_attr($kepler_caption);
    $kepler_height = absint($kepler_height);
    
    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

    return "<div class='google-map {$css_class}' data-zoom='{$kepler_zoom}' 
					data-address='{$kepler_address}' 
					data-caption='{$kepler_caption}' 
					data-maptype='{$kepler_type}'
					data-popup='{$kepler_popup}'
                                        data-mapheight='{$kepler_height}'>
					<p>" . esc_html__('This will be replaced with the Google Map.', 'kepler-wp') . "</p>
				</div>";
}

add_shortcode('kepler_gmaps', 'kepler_gmaps_func');

add_action('init', 'kepler_integrate_vc_gmaps');

// integrates the custom element in the visual composer
function kepler_integrate_vc_gmaps() {
    vc_map(
            array(
                "name" => esc_html__("Google Map", 'kepler-wp'),
                "base" => "kepler_gmaps",
                "category" => esc_html__('Kepler Elements', 'kepler-wp'),
                "icon" => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                "params" => array(
                    array(
                        "type" => "textfield",
                        'holder' => 'div',
                        "heading" => esc_html__("Address", 'kepler-wp'),
                        "param_name" => "kepler_address",
                        "description" => esc_html__("The address where the map is centered", 'kepler-wp')
                    ),
                    array(
                        "type" => "textfield",
                        "heading" => esc_html__("Pinpoint caption", 'kepler-wp'),
                        "param_name" => "kepler_caption",
                        "description" => esc_html__("Specify text that will appear when you click on the pin", 'kepler-wp')
                    ),
                    array(
                        'type' => 'checkbox',
                        'heading' => esc_html__('Pinpoint caption popup', 'kepler-wp'),
                        'param_name' => 'kepler_popup',
                        'value' => array(esc_html__('Show', 'kepler-wp') => 'true')
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Zoom', 'kepler-wp'),
                        'param_name' => 'kepler_zoom',
                        'value' => '16',
                        'description' => esc_html__('Specify a zoom value between 5 and 20', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Map height', 'kepler-wp'),
                        'param_name' => 'kepler_height',
                        'value' => '635',
                        'description' => esc_html__('Specify a height numeric value', 'kepler-wp')
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Map type', 'kepler-wp'),
                        'param_name' => 'kepler_type',
                        'value' => array(
                            esc_html__('ROADMAP', 'kepler-wp') => 'ROADMAP',
                            esc_html__('TERRAIN', 'kepler-wp') => 'TERRAIN',
                            esc_html__('SATELLITE', 'kepler-wp') => 'SATELLITE',
                            esc_html__('HYBRID', 'kepler-wp') => 'HYBRID'
                        )
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}

class WPBakeryShortCode_kepler_gmaps extends WPBakeryShortCode {
    
}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Headline Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_headline_func($atts) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_title' => '',
    'kepler_spacing' => '',
    'kepler_align' => '',
    'css' => '' ), $atts));

    $kepler_title = esc_html($kepler_title);

    if ($kepler_spacing != '') {
        $kepler_spacing = intval($kepler_spacing);
        $spacing = " style='margin-bottom:{$kepler_spacing}px !important;'";
    } else {
        $spacing = '';
    }
    
    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

    return "<div class='headline{$kepler_align} {$css_class}'{$spacing}><h2>{$kepler_title}</h2></div>";
}

add_shortcode('kepler_headline', 'kepler_headline_func');

add_action('init', 'kepler_integrate_vc_headline');

// integrates the custom element in the visual composer
function kepler_integrate_vc_headline() {
    vc_map(
            array(
                'name' => esc_html__('Headline', 'kepler-wp'),
                'base' => 'kepler_headline',
                'category' => esc_html__('Kepler Elements', 'kepler-wp'),
                'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'holder' => 'div',
                        'heading' => esc_html__('Title', 'kepler-wp'),
                        'param_name' => 'kepler_title',
                        'description' => esc_html__('Specify a title', 'kepler-wp')
                    ),
                    array(
                        'type' => 'checkbox',
                        'heading' => esc_html__('Align', 'kepler-wp'),
                        'param_name' => 'kepler_align',
                        'value' => array(esc_html__('Center', 'kepler-wp') => '-center')
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Bottom spacing', 'kepler-wp'),
                        'param_name' => 'kepler_spacing',
                        'value' => esc_html__('default', 'kepler-wp'),
                        'description' => esc_html__('Specify a a numeric amount for bottom spacing', 'kepler-wp')
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}

class WPBakeryShortCode_kepler_headline extends WPBakeryShortCode {
    
}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Icon Box Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_icon_boxes_func($atts, $content = null) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_icon' => '',
    'kepler_link' => '',
    'kepler_title' => '',
    'kepler_style' => '1',
    'kepler_align' => '',
    'css' => '' ), $atts));

    if (trim($content) != '') {
        $content = wp_kses_post($content);
        $content_p = "<p>{$content}</p>";
    }

    $newtab = $link_start = $link_end = $icon = '';

    if (trim($kepler_icon) != '') {
        $kepler_icon = esc_attr($kepler_icon);
        $icon = "<i class='{$kepler_icon}'></i>";
    }

    $link_details = vc_build_link($kepler_link);

    if (trim($link_details['url']) != '') {

        if ($link_details['target'] !== '') {
            $newtab = "target='{$link_details['target']}'";
        }

        $link_details['url'] = esc_url($link_details['url']);
        $link_start = "<a href='{$link_details['url']}' {$newtab}>";
        $link_end = "</a>";
    }

    if (trim($link_details['title']) != '') {
        $link_details['title'] = esc_html($link_details['title']);
        $read_more = "<a href='{$link_details['url']}'>{$link_details['title']}</a>";
    } else {
        $read_more = '';
    }
    
    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

    if ($kepler_style == '1') {
        if (trim($kepler_title) != '') {
            $kepler_title = esc_html($kepler_title);
            $box_title = "<h5>{$link_start}{$kepler_title}{$link_end}</h5>";
        } else {
            $box_title = '';
        }
        return "<div class='icon-box-1{$kepler_align} {$css_class}'>{$icon}<div class='icon-box-content'>{$box_title}{$content_p}{$read_more}</div></div>";
    } else if ($kepler_style == '4') {
        if (trim($kepler_title) != '') {
            $kepler_title = esc_html($kepler_title);
            $box_title = "<h5>{$link_start}{$kepler_title}{$link_end}</h5>";
        } else {
            $box_title = '';
        }
        return "<div class='icon-box-4 {$css_class}'>{$icon}<div class='icon-box-content'>{$box_title}{$content}{$read_more}</div></div>";
    } else {
        if (trim($kepler_title) != '') {
            $kepler_title = esc_html($kepler_title);
            $box_title = "<h5>{$link_start}{$kepler_title}{$link_end}</h5>";
        } else {
            $box_title = '';
        }
        return "<div class='icon-box-{$kepler_style} {$css_class}'>{$icon}{$box_title}<br class='clear'>{$content_p}{$read_more}</div>";
    }
}

add_shortcode('kepler_icon_boxes', 'kepler_icon_boxes_func');
add_action('init', 'kepler_integrate_vc_icon_boxes');

// integrates the custom element in the visual composer
function kepler_integrate_vc_icon_boxes() {
    vc_map(
            array(
                'name' => esc_html__('Icon Box', 'kepler-wp'),
                'base' => 'kepler_icon_boxes',
                'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                'category' => esc_html__('Kepler Elements', 'kepler-wp'),
                'params' => array(
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Iconbox Style', 'kepler-wp'),
                        'param_name' => 'kepler_style',
                        'value' => array(
                            esc_html__('Style 1', 'kepler-wp') => '1',
                            esc_html__('Style 2', 'kepler-wp') => '2',
                            esc_html__('Style 3', 'kepler-wp') => '3',
                            esc_html__('Style 4', 'kepler-wp') => '4'
                        )
                    ),
                    array(
                        'type' => 'textfield',
                        'holder' => 'div',
                        'heading' => esc_html__('Title', 'kepler-wp'),
                        'param_name' => 'kepler_title',
                        'value' => esc_html__('Title', 'kepler-wp')
                    ),
                    array(
                        'type' => 'checkbox',
                        'heading' => esc_html__('Text align', 'kepler-wp'),
                        'param_name' => 'kepler_align',
                        'dependency' => array(
                            'element' => 'kepler_style',
                            'value' => '1'
                        ),
                        'value' => array(esc_html__('Center', 'kepler-wp') => ' text-center')
                    ),
                    array(
                        'type' => 'vc_link',
                        'heading' => esc_html__('Iconbox link', 'kepler-wp'),
                        'param_name' => 'kepler_link',
                        'description' => esc_html__('Specify an optional link pointing to a details page', 'kepler-wp')
                    ),
                    array(
                        'type' => 'kepler_icomoon_icons_param',
                        'heading' => esc_html__('Select icon', 'kepler-wp'),
                        'param_name' => 'kepler_icon',
                        'description' => esc_html__('Select the icon you want', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textarea_html',
                        'heading' => esc_html__('Content', 'kepler-wp'),
                        'param_name' => 'content',
                        'description' => esc_html__('Add description text for the iconbox', 'kepler-wp')
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}

class WPBakeryShortCode_kepler_icon_boxes extends WPBakeryShortCode {
    
}
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       VC CUSTOM LOGOS ELEMENTS
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_logos_container_func($atts, $content = null) { 
    $css = '';
    extract(shortcode_atts(array(
    'kepler_class' => '',
    'css' => '' ), $atts));

    $content = wpb_js_remove_wpautop($content, false);
    $kepler_class = esc_attr($kepler_class);

    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);
    
    return "<ul class='clients-logos {$kepler_class} {$css_class}'>{$content}</ul>";
}

add_shortcode('kepler_logos_container', 'kepler_logos_container_func');

function kepler_logos_func($atts) { 
    extract(shortcode_atts(array(
    'kepler_image' => '',
    'kepler_link' => '' ), $atts));

    if ($kepler_image == null) {
        $image = '';
    } else {
        $image_data = wp_get_attachment_image_src($kepler_image, 'full');
        $image_url = esc_url($image_data[0]);
        $image = "<img src='{$image_url}' alt=''>";
    }

    $link_details = vc_build_link($kepler_link);

    if (trim($link_details['url']) != '') {

        if ($link_details['target'] !== '') {
            $newtab = "target='{$link_details['target']}'";
        }

        $link_details['url'] = esc_url($link_details['url']);
        $link_start = "<a href='{$link_details['url']}' {$newtab} title='{$link_details['title']}'>";
        $link_end = "</a>";
    } else {
        $link_start = $link_end = '';
    }

    return "<li>{$link_start}{$image}{$link_end}</li>";
}

add_shortcode('kepler_logos', 'kepler_logos_func');
add_action('init', 'kepler_integrate_vc_logos_components');

// integrates the custom element in the visual composer
function kepler_integrate_vc_logos_components() {
    vc_map(array(
        'name' => esc_html__('Logos container', 'kepler-wp'),
        'base' => 'kepler_logos_container',
        'category' => esc_html__('Kepler Elements', 'kepler-wp'),
        'as_parent' => array('only' => 'kepler_logos'),
        'content_element' => true,
        'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
        'show_settings_on_create' => false,
        'params' => array(
            array(
                'type' => 'textfield',
                'heading' => esc_html__('Optional class', 'kepler-wp'),
                'holder' => 'div',
                'param_name' => 'kepler_class',
                'description' => esc_html__('Specify an optional class', 'kepler-wp')
            ),
            array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
        ),
        'js_view' => 'VcColumnView'
    ));
    vc_map(array(
        'name' => esc_html__('Logo element', 'kepler-wp'),
        'base' => 'kepler_logos',
        'category' => esc_html__('Kepler Elements', 'kepler-wp'),
        'content_element' => true,
        'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
        'as_child' => array('only' => 'kepler_logos_container'),
        'params' => array(
            array(
                'type' => 'attach_image',
                'heading' => esc_html__('Logo Image', 'kepler-wp'),
                'param_name' => 'kepler_image',
                'description' => esc_html__('Add a logo image', 'kepler-wp')
            ),
            array(
                'type' => 'vc_link',
                'heading' => esc_html__('Logo link', 'kepler-wp'),
                'param_name' => 'kepler_link',
                'description' => esc_html__('Specify an optional link pointing to a details page', 'kepler-wp')
            ),
        )
    ));
}

if (class_exists('WPBakeryShortCodesContainer')) {

    class WPBakeryShortCode_kepler_logos_container extends WPBakeryShortCodesContainer {
        
    }

}
if (class_exists('WPBakeryShortCode')) {

    class WPBakeryShortCode_kepler_logos extends WPBakeryShortCode {
        
    }

}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Milestone Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_milestones_func($atts, $content = null) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_stop' => '100',
    'kepler_extra' => '',
    'kepler_icon' => '',
    'kepler_speed' => '2000',
    'css' => '' ), $atts));

    $content = esc_html($content);
    $extra = $icon = '';

    $kepler_stop = absint($kepler_stop);
    $kepler_speed = absint($kepler_speed);

    if (trim($kepler_extra) != '') {
        $kepler_extra = esc_html($kepler_extra);
        $extra = "<span>{$kepler_extra}</span>";
    }

    if (trim($kepler_icon) != '') {
        $kepler_icon = esc_attr($kepler_icon);
        $icon = "<i class='{$kepler_icon}'></i>";
    }
    
$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);
    
    return "<div class='milestone {$css_class}'>{$icon}<div class='milestone-content'>
    <span class='milestone-value' data-stop='{$kepler_stop}' data-speed='{$kepler_speed}'></span>
            {$extra}<div class='milestone-description'>{$content}</div></div></div>";
}

add_shortcode('kepler_milestones', 'kepler_milestones_func');

add_action('init', 'kepler_integrate_vc_milestones');

// integrates the custom element in the visual composer
function kepler_integrate_vc_milestones() {
    vc_map(
            array(
                'name' => esc_html__('Milestone', 'kepler-wp'),
                'base' => 'kepler_milestones',
                'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                'category' => esc_html__('Kepler Elements', 'kepler-wp'),
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Number', 'kepler-wp'),
                        'param_name' => 'kepler_stop',
                        'value' => '100',
                        'description' => esc_html__('The final value will animate to, from 0 to the number provided by you', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Speed', 'kepler-wp'),
                        'param_name' => 'kepler_speed',
                        'value' => '2000',
                        'description' => esc_html__('Specify the animation speed', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textfield',
                        'holder' => 'div',
                        'heading' => esc_html__('Milestone Details', 'kepler-wp'),
                        'param_name' => 'content'
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Extra', 'kepler-wp'),
                        'param_name' => 'kepler_extra',
                        'description' => esc_html__('Add an extra marker beside the milestone number (optional)', 'kepler-wp')
                    ),
                    array(
                        'type' => 'kepler_icomoon_icons_param',
                        'heading' => esc_html__('Select icon', 'kepler-wp'),
                        'param_name' => 'kepler_icon',
                        'description' => esc_html__('Select the icon you want', 'kepler-wp')
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}

class WPBakeryShortCode_kepler_milestones extends WPBakeryShortCode {
    
}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Pie Chart Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_pie_chart_func($atts) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_data_barcolor' => '#000000',
    'kepler_data_trackcolor' => '',
    'kepler_center_value' => '',
    'kepler_percent' => '10',
    'kepler_linewidth' => '1',
    'kepler_barsize' => '230',
    'kepler_icon' => '',
    'css' => '' ), $atts));

    $kepler_data_barcolor = esc_attr($kepler_data_barcolor);
    $kepler_data_trackcolor = esc_attr($kepler_data_trackcolor);

    $kepler_percent = absint($kepler_percent);
    $kepler_linewidth = absint($kepler_linewidth);
    $kepler_barsize = absint($kepler_barsize);
    $kepler_center_value = esc_html($kepler_center_value);

    if (trim($kepler_data_barcolor) == '') {
        $kepler_data_barcolor = 'transparent';
    }
    if (trim($kepler_data_trackcolor) == '') {
        $kepler_data_trackcolor = 'transparent';
    }
    if (trim($kepler_icon) != '') {
        $kepler_icon = esc_attr($kepler_icon);
        $icon = "<span class='pie-chart-custom-text'><i class='{$kepler_icon}'></i></span>";
    }
    
$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);
    
    return "<div class='pie-chart {$css_class}' data-percent='{$kepler_percent}' data-barColor='{$kepler_data_barcolor}' data-trackColor='{$kepler_data_trackcolor}' 
            data-lineWidth='{$kepler_linewidth}' data-barSize='{$kepler_barsize}'>{$icon}<div class='pie-chart-percent'><span></span>%</div></div><div class='pie-chart-description'>{$kepler_center_value}</div>";
}

add_shortcode('kepler_pie_chart', 'kepler_pie_chart_func');
add_action('init', 'kepler_integrate_vc_pie_chart');

// integrates the custom element in the visual composer
function kepler_integrate_vc_pie_chart() {
    vc_map(
            array(
                'name' => esc_html__('Pie Chart', 'kepler-wp'),
                'base' => 'kepler_pie_chart',
                'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                'category' => esc_html__('Kepler Elements', 'kepler-wp'),
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'holder' => 'div',
                        'heading' => esc_html__('Chart top description', 'kepler-wp'),
                        'param_name' => 'kepler_center_value',
                    ),
                    array(
                        'type' => 'textfield',
                        'holder' => 'div',
                        'heading' => esc_html__('Chart percent', 'kepler-wp'),
                        'param_name' => 'kepler_percent',
                        'value' => '10',
                        'description' => esc_html__('Specify a value from 0 to 100', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Pie Chart Bar Thickness', 'kepler-wp'),
                        'param_name' => 'kepler_linewidth',
                        'value' => '1',
                        'description' => esc_html__('Numeric value between 5 and 15', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Bar Width', 'kepler-wp'),
                        'param_name' => 'kepler_barsize',
                        'value' => '230',
                        'description' => esc_html__('Specify bar width', 'kepler-wp')
                    ),
                    array(
                        'type' => 'colorpicker',
                        'heading' => esc_html__('Bar Color', 'kepler-wp'),
                        'param_name' => 'kepler_data_barcolor',
                        'value' => '#000000',
                        'description' => esc_html__('Specify Bar-Color', 'kepler-wp')
                    ),
                    array(
                        'type' => 'colorpicker',
                        'class' => 'piechart_options_display_trigger',
                        'heading' => esc_html__('Track Color', 'kepler-wp'),
                        'param_name' => 'kepler_data_trackcolor',
                        'description' => esc_html__('Specify Track-Color', 'kepler-wp')
                    ),
                    array(
                        'type' => 'kepler_icomoon_icons_param',
                        'heading' => esc_html__('Select icon', 'kepler-wp'),
                        'param_name' => 'kepler_icon',
                        'description' => esc_html__('Select the icon you want', 'kepler-wp')
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}
class WPBakeryShortCode_kepler_pie_chart extends WPBakeryShortCode {
    
}
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       VC CUSTOM PROCESS COMPONENTS ELEMENTS
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_process_container_func($atts, $content = null) { 
    $css = '';
    extract(shortcode_atts(array(
    'kepler_class' => '',
    'css' => '' ), $atts));

    $content = wpb_js_remove_wpautop($content, false);
    $kepler_class = esc_attr($kepler_class);
    $class_part = '';

    $content_elements = explode("<li>", $content);
    $count = count($content_elements);
    if ($count <= 3) {
        $class_part = 'two-items';
    } else if ($count == 4) {
        $class_part = 'three-items';
    } else if ($count == 5) {
        $class_part = 'four-items';
    } else {
        $class_part = 'five-items';
    }
    
    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

    return "<div class='horizontal-process-builder {$class_part} {$kepler_class} {$css_class}'>{$content}</div>";
}

add_shortcode('kepler_process_container', 'kepler_process_container_func');

function kepler_process_func($atts, $content = null) { 
    extract(shortcode_atts(array(
    'kepler_title' => '',
    'kepler_icon' => ''), $atts));

    if (trim($kepler_icon)) {
        $kepler_icon = esc_attr($kepler_icon);
        $top_part = "<h5><span><i class='{$kepler_icon}'></i><span></h5>";
    } else {
        $kepler_title = esc_html($kepler_title);
        $top_part = "<h5><span>{$kepler_title}<span></h5>";
    }

    $content = wp_kses_post($content);

    return "<li>{$top_part}<div class='process-description'><p>{$content}</p></div></li>";
}

add_shortcode('kepler_process', 'kepler_process_func');
add_action('init', 'kepler_integrate_vc_process_components');

// integrates the custom element in the visual composer
function kepler_integrate_vc_process_components() {
    vc_map(array(
        'name' => esc_html__('Our Process', 'kepler-wp'),
        'base' => 'kepler_process_container',
        'category' => esc_html__('Kepler Elements', 'kepler-wp'),
        'as_parent' => array('only' => 'kepler_process'),
        'content_element' => true,
        'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
        'show_settings_on_create' => false,
        'params' => array(
            array(
                'type' => 'textfield',
                'heading' => esc_html__('Optional class', 'kepler-wp'),
                'holder' => 'div',
                'param_name' => 'kepler_class',
                'description' => esc_html__('Specify an optional class', 'kepler-wp')
            ),
            array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
        ),
        'js_view' => 'VcColumnView'
    ));
    vc_map(array(
        'name' => esc_html__('Process Step', 'kepler-wp'),
        'base' => 'kepler_process',
        'category' => esc_html__('Kepler Elements', 'kepler-wp'),
        'content_element' => true,
        'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
        'as_child' => array('only' => 'kepler_process_container'),
        'params' => array(
            // add params same as with any other content element
            array(
                'type' => 'kepler_icomoon_icons_param',
                'holder' => 'div',
                'heading' => esc_html__('Select icon', 'kepler-wp'),
                'param_name' => 'kepler_icon',
                'description' => esc_html__('Select the icon you want', 'kepler-wp')
            ),
            array(
                'type' => 'textfield',
                'heading' => esc_html__('Title', 'kepler-wp'),
                'holder' => 'div',
                'param_name' => 'kepler_title',
                'description' => esc_html__('Specify the title of the process', 'kepler-wp')
            ),
            array(
                'type' => 'textarea_html',
                'heading' => esc_html__('Details', 'kepler-wp'),
                'param_name' => 'content',
                'description' => esc_html__('Specify the details of the process step', 'kepler-wp')
            )
        )
    ));
}

if (class_exists('WPBakeryShortCodesContainer')) {

    class WPBakeryShortCode_kepler_process_container extends WPBakeryShortCodesContainer {
        
    }

}
if (class_exists('WPBakeryShortCode')) {

    class WPBakeryShortCode_kepler_process extends WPBakeryShortCode {
        
    }

}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Pricing Table Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_pricing_table_func($atts) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_price' => '25',
    'kepler_name' => '',
    'kepler_specifications' => '',
    'kepler_link' => '',
    'kepler_cost_type' => '$',
    'kepler_cost_time' => esc_html__("Month", 'kepler-wp'),
    'css' => '' ), $atts));

    $specifications_elements = mb_split('<br />', $kepler_specifications);
    $kepler_name = esc_html($kepler_name);
    $kepler_price = esc_html($kepler_price);
    $kepler_cost_type = esc_html($kepler_cost_type);
    $kepler_cost_time = esc_html($kepler_cost_time);

    $link_details = vc_build_link($kepler_link);
    $link_details['target'] = esc_attr($link_details['target']);
    $link_details['url'] = esc_url($link_details['url']);
    $link_details['title'] = esc_html($link_details['title']);

    $newtab = $table_link = $specifications_list = '';

    if ($link_details['target'] !== '') {
        $newtab = "target='{$link_details['target']}'";
    }

    if (trim($link_details['url']) != '' || trim($link_details['title']) != '') {
        $table_link = "<a class='btn btn-white' href='{$link_details['url']}' {$newtab}>{$link_details['title']}</a>";
    }

    // Loops through each specifications row
    foreach ($specifications_elements as $element) {
        $specifications_list.='<li>' . esc_html($element) . '</li>';
    }
    
$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);
    
    return "<div class='pricing-table {$css_class}'>
                            <div class='pricing-table-header'>
                                <h4>{$kepler_name}</h4>
                                <h1>{$kepler_price}<sup>{$kepler_cost_type}</sup><small>{$kepler_cost_time}</small></h1>                
                            </div>
                            <div class='pricing-table-offer'>
                                <ul>{$specifications_list}</ul>
                            </div> 
                            {$table_link}  
                        </div>";
}

add_shortcode('kepler_pricing_table', 'kepler_pricing_table_func');

add_action('init', 'kepler_integrate_vc_pricing_table');

// integrates the custom element in the visual composer
function kepler_integrate_vc_pricing_table() {
    vc_map(
            array(
                'name' => esc_html__('Pricing Table', 'kepler-wp'),
                'base' => 'kepler_pricing_table',
                'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                'category' => esc_html__('Kepler Elements', 'kepler-wp'),
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'holder' => 'div',
                        'heading' => esc_html__('Plan name', 'kepler-wp'),
                        'param_name' => 'kepler_name',
                        'value' => esc_html__('Starter edition', 'kepler-wp'),
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Cost', 'kepler-wp'),
                        'param_name' => 'kepler_price',
                        'value' => '25',
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Cost type', 'kepler-wp'),
                        'param_name' => 'kepler_cost_type',
                        'value' => '$',
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Per', 'kepler-wp'),
                        'param_name' => 'kepler_cost_time',
                        'value' => esc_html__('Month', 'kepler-wp'),
                    ),
                    array(
                        'type' => 'textarea',
                        'heading' => esc_html__('Plan features (add one per line)', 'kepler-wp'),
                        'param_name' => 'kepler_specifications',
                        'description' => esc_html__('Write the specifications', 'kepler-wp')
                    ),
                    array(
                        'type' => 'vc_link',
                        'heading' => esc_html__('Read more button', 'kepler-wp'),
                        'param_name' => 'kepler_link',
                        'description' => esc_html__('Specify an optional link pointing to a details page', 'kepler-wp')
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}

class WPBakeryShortCode_kepler_pricing_table extends WPBakeryShortCode {
    
}
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Progress Bar Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_progress_bar_func($atts, $content = null) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_width' => '90',
    'css' => '' ), $atts));

    $content = esc_html($content);
    $kepler_width = absint($kepler_width);

    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);
    
    return "<div class='fixed {$css_class}'><div class='progress-bar-description'>{$content}<span>{$kepler_width}%</span>
        </div><div class='progress-bar'><span class='progress-bar-outer' data-width='{$kepler_width}'> 
        <span class='progress-bar-inner'></span></span></div></div>";
}

add_shortcode('kepler_progress_bar', 'kepler_progress_bar_func');

add_action('init', 'kepler_integrate_vc_progress_bar');

// integrates the progess bar element in the visual composer
function kepler_integrate_vc_progress_bar() {
    vc_map(
            array(
                'name' => esc_html__('Progress Bar', 'kepler-wp'),
                'base' => 'kepler_progress_bar',
                'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                'category' => esc_html__('Kepler Elements', 'kepler-wp'),
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'holder' => 'div',
                        'heading' => esc_html__('Title', 'kepler-wp'),
                        'param_name' => 'content',
                        'value' => esc_html__('title', 'kepler-wp'),
                        'description' => esc_html__('The title of the progress bar', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Value', 'kepler-wp'),
                        'param_name' => 'kepler_width',
                        'value' => '90',
                        'description' => esc_html__('Specify a value between 1 and 100, it represents the loaded percentage', 'kepler-wp')
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}

class WPBakeryShortCode_kepler_progress_bar extends WPBakeryShortCode {
    
}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       VC CUSTOM SIMPLE SLIDER ELEMENTS
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_simple_slider_container_func($atts, $content = null) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_class' => '',
    'css' => '' ), $atts));

    $content = wpb_js_remove_wpautop($content, false);
    $kepler_class = esc_attr($kepler_class);
    
    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

return "<div class='images-slider {$kepler_class} {$css_class}'><div class='slides'>{$content}</div></div>";
}

add_shortcode('kepler_simple_slider_container', 'kepler_simple_slider_container_func');

add_action('init', 'kepler_integrate_vc_simple_slider_components');

// integrates the custom element in the visual composer
function kepler_integrate_vc_simple_slider_components() {
    vc_map(array(
        'name' => esc_html__('Simple slider', 'kepler-wp'),
        'base' => 'kepler_simple_slider_container',
        'category' => esc_html__('Kepler Elements', 'kepler-wp'),
        'as_parent' => array('except' => 'kepler_simple_slider_container'),
        'content_element' => true,
        'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
        'show_settings_on_create' => false,
        'params' => array(
            array(
                'type' => 'textfield',
                'holder' => 'div',
                'heading' => esc_html__('Optional Class', 'kepler-wp'),
                'param_name' => 'kepler_class',
                'description' => esc_html__('Specify an optional extra class', 'kepler-wp')
            ),
            array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
        ),
        'js_view' => 'VcColumnView'
    ));
}

if (class_exists('WPBakeryShortCodesContainer')) {

    class WPBakeryShortCode_kepler_simple_slider_container extends WPBakeryShortCodesContainer {
        
    }

}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Social Media Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_social_media_func($atts) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_social_icon' => '',
    'kepler_social_link' => '',
    'css' => '' ), $atts));

    $output = '';

    $kepler_social_icon = esc_attr($kepler_social_icon);

    $icon_parts = explode('-', $kepler_social_icon);

    if (isset($icon_parts[1])) {
        $icon = $icon_parts[1];

        if ($icon == 'stack') {
            $icon.='-' . $icon_parts[2];
        }
    }

    $kepler_social_link = esc_url($kepler_social_link);
    $icon = esc_attr($icon);
    
        $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);
    
    return "<a href='{$kepler_social_link} {$css_class}' class='{$icon}-icon social-icon' target='_blank'><i class='{$kepler_social_icon}'></i></a>";
}

add_shortcode('kepler_social_media', 'kepler_social_media_func');
add_action('init', 'kepler_integrate_vc_social_media');

// integrates the custom element in the visual composer
function kepler_integrate_vc_social_media() {
    vc_map(array(
        "name" => esc_html__("Social Media", 'kepler-wp'),
        "base" => "kepler_social_media",
        "icon" => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
        "category" => esc_html__('Kepler Elements', 'kepler-wp'),
        "params" => array(
            array(
                "type" => "kepler_fa_icons_param",
                'holder' => 'div',
                "heading" => esc_html__("Social icon", 'kepler-wp'),
                "param_name" => "kepler_social_icon",
                "description" => esc_html__("Select social icon", 'kepler-wp')
            ),
            array(
                "type" => "textfield",
                'holder' => 'div',
                "heading" => esc_html__("Social link", 'kepler-wp'),
                "param_name" => "kepler_social_link",
                "description" => esc_html__("Specify social link", 'kepler-wp')
            ),
            array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
        )
            )
    );
}
class WPBakeryShortCode_kepler_social_media extends WPBakeryShortCode {
    
}
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       VC CUSTOM TEAM MEMBER ELEMENTS
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// the short code function for the team member elements
function kepler_team_member_func($atts) {
    $css = '';
    extract(shortcode_atts(array(
        'kepler_name' => '',
        'kepler_job' => '',
        'kepler_image' => '',
        'kepler_link' => '',
        'css' => ''), $atts));

    $kepler_name = esc_html($kepler_name);
    $kepler_job = esc_html($kepler_job);

    if ($kepler_image == null) {
        $image = '';
    } else {
        $image_data = wp_get_attachment_image_src($kepler_image, 'kepler_team_size');
        $image_url = esc_url($image_data[0]);
        $image = "<img src='{$image_url}' alt=''>";
    }

    $link_details = vc_build_link($kepler_link);

    if (trim($link_details['url']) != '') {

        if ($link_details['target'] !== '') {
            $newtab = "target='{$link_details['target']}'";
        } else {
            $newtab = '';
        }

        $link_details['title'] = esc_attr($link_details['title']);
        $link_details['url'] = esc_url($link_details['url']);
        $link_start = "<a href='{$link_details['url']}' title='{$link_details['title']}' {$newtab}>";
        $link_end = "</a>";
    } else {
        $link_start = $link_end = '';
    }
    
    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

    return "<div class='team-member {$css_class}'>{$link_start}{$image}{$link_end}
            <div class='team-member-details'><h5>{$kepler_name}</h5><p>{$kepler_job}</p></div></div>";
}

add_shortcode('kepler_team_member', 'kepler_team_member_func');
add_action('init', 'kepler_integrate_vc_team_member');

// integrates the custom element in the visual composer
function kepler_integrate_vc_team_member() {
    vc_map(
            array(
                'name' => esc_html__('Team Member', 'kepler-wp'),
                'base' => 'kepler_team_member',
                'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                'category' => esc_html__('Kepler Elements', 'kepler-wp'),
                'params' => array(
                    array(
                        'type' => 'attach_image',
                        'heading' => esc_html__('Image', 'kepler-wp'),
                        'param_name' => 'kepler_image',
                        'description' => esc_html__('Add the image of the team member', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textfield',
                        'holder' => 'div',
                        'heading' => esc_html__('Name', 'kepler-wp'),
                        'param_name' => 'kepler_name',
                        'value' => esc_html__('Sample name', 'kepler-wp'),
                        'description' => esc_html__('Specify the name of the member', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Job Title', 'kepler-wp'),
                        'param_name' => 'kepler_job',
                        'value' => esc_html__('Job Title', 'kepler-wp')
                    ),
                    array(
                        'type' => 'vc_link',
                        'heading' => esc_html__('Link title &amp; URL', 'kepler-wp'),
                        'param_name' => 'kepler_link',
                        'description' => esc_html__('Specify the link pointing to another page', 'kepler-wp')
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}
class WPBakeryShortCode_kepler_team_member extends WPBakeryShortCode {
    
}
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Testimonial Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_testimonial_func($atts, $content = null) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_name' => '',
    'kepler_image' => '',
    'kepler_job' => '',
    'css' => '' ), $atts));

    $kepler_name = esc_html($kepler_name);
    $kepler_job = esc_html($kepler_job);
    $specifications_elements = mb_split('<br />', $content);
    $specifications_list = '';
    // Loops through each specifications row
    foreach ($specifications_elements as $element) {
        $specifications_list.= esc_html($element) . '<br />';
    }

    if (trim($kepler_job) != '') {
        $testimonial_job = "<small>{$kepler_job}</small>";
    }

    if ($kepler_image == null) {
        $image = '';
    } else {
        $image_data = wp_get_attachment_image_src($kepler_image, 'kepler_iconbox_size');
        $image_url = esc_url($image_data[0]);
        $image = "<img src='{$image_url}' alt=''>";
    }
    
    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);
    
    return "<div class='testimonial {$css_class}'><blockquote><p>{$specifications_list}</p></blockquote>{$image}<h5>{$kepler_name}</h5><h6>{$testimonial_job}</h6></div>";
}

add_shortcode('kepler_testimonial', 'kepler_testimonial_func');
add_action('init', 'kepler_integrate_vc_testimonial');

// integrates the custom element in the visual composer
function kepler_integrate_vc_testimonial() {
    vc_map(
            array(
                'name' => esc_html__('Testimonial', 'kepler-wp'),
                'base' => 'kepler_testimonial',
                'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                'category' => esc_html__('Kepler Elements', 'kepler-wp'),
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'holder' => 'div',
                        'heading' => esc_html__('Name', 'kepler-wp'),
                        'param_name' => 'kepler_name',
                        'value' => esc_html__('Sample name', 'kepler-wp'),
                        'description' => esc_html__('Specify the name of the testimonial author', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Job', 'kepler-wp'),
                        'param_name' => 'kepler_job',
                        'description' => esc_html__('Specify the job of the testimonial author', 'kepler-wp')
                    ),
                    array(
                        'type' => 'attach_image',
                        'heading' => esc_html__('Image', 'kepler-wp'),
                        'param_name' => 'kepler_image',
                        'description' => esc_html__('Add an image', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textarea',
                        'heading' => esc_html__('Testimonial quote', 'kepler-wp'),
                        'param_name' => 'content',
                        'description' => esc_html__('Specify the text of the testimonial', 'kepler-wp')
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}
class WPBakeryShortCode_kepler_testimonial extends WPBakeryShortCode {
    
}
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       VC CUSTOM TESTIMONIAL SLIDER ELEMENTS
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_testimonial_slider_container_func($atts, $content = null) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_class' => '',
    'css' => '' ), $atts));

    $content = wpb_js_remove_wpautop($content, false);

    $kepler_class = esc_attr($kepler_class);
    
    $css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);

    return "<div class='testimonial-slider {$kepler_class} {$css_class}'><div class='slides'>{$content}</div></div>";
}

add_shortcode('kepler_testimonial_slider_container', 'kepler_testimonial_slider_container_func');

add_action('init', 'kepler_integrate_vc_testimonial_slider_components');

// integrates the custom element in the visual composer
function kepler_integrate_vc_testimonial_slider_components() {
    vc_map(array(
        'name' => esc_html__('Testimonial Slider Container', 'kepler-wp'),
        'base' => 'kepler_testimonial_slider_container',
        'category' => esc_html__('Kepler Elements', 'kepler-wp'),
        'as_parent' => array('only' => 'kepler_testimonial'),
        'content_element' => true,
        'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
        'show_settings_on_create' => false,
        'params' => array(
            array(
                'type' => 'textfield',
                'holder' => 'div',
                'heading' => esc_html__('Optional Class', 'kepler-wp'),
                'param_name' => 'kepler_class',
                'value' => '',
                'description' => esc_html__('Specify an optional extra class', 'kepler-wp')
            ),
            array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
        ),
        'js_view' => 'VcColumnView'
    ));
}

if (class_exists('WPBakeryShortCodesContainer')) {

    class WPBakeryShortCode_kepler_testimonial_slider_container extends WPBakeryShortCodesContainer {
        
    }

}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
//                       Twitter Component
//
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function kepler_twitter_elements_func($atts) {
    $css = '';
    extract(shortcode_atts(array(
    'kepler_id' => '',
    'kepler_link' => '',
    'kepler_count' => '1',
    'css' => '' ), $atts));

    $kepler_id = esc_attr($kepler_id);
    $kepler_count = absint($kepler_count);

    $link_details = vc_build_link($kepler_link);

    if (trim($link_details['url']) != '') {

        if ($link_details['target'] !== '') {
            $newtab = "target='{$link_details['target']}'";
        } else {
            $newtab = '';
        }

        $link_details['title'] = esc_attr($link_details['title']);
        $link_details['url'] = esc_url($link_details['url']);
        $link = "<p class='text-center text-uppercase'><a href='{$link_details['url']}' {$newtab}>{$link_details['title']}</a></p>";
    } else {
        $link = '';
    }
    
$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class($css, ' '), '', $atts);
    $css_class = esc_attr($css_class);
    
    return "<div class='kepler_widget_latest_tweets {$css_class}'><div class='kepler-tweet-list' data-account-id='{$kepler_id}' data-items='{$kepler_count}'></div>{$link}</div>";
}

add_shortcode('kepler_twitter_elements', 'kepler_twitter_elements_func');

add_action('init', 'kepler_integrate_vc_twitter_elements');

// integrates the custom element in the visual composer
function kepler_integrate_vc_twitter_elements() {
    vc_map(
            array(
                'name' => esc_html__('Tweets', 'kepler-wp'),
                'base' => 'kepler_twitter_elements',
                'icon' => get_template_directory_uri() . '/framework/admin/images/vc-icon.png',
                'category' => esc_html__('Kepler Elements', 'kepler-wp'),
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Account id', 'kepler-wp'),
                        'param_name' => 'kepler_id',
                        'description' => esc_html__('You can use sites like gettwitterid.com or tweeterid.com to find your id.', 'kepler-wp')
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Number of tweets', 'kepler-wp'),
                        'param_name' => 'kepler_count',
                        'value' => '1',
                        'description' => esc_html__('Specify the number of tweets to show', 'kepler-wp')
                    ),
                    array(
                        'type' => 'vc_link',
                        'heading' => esc_html__('Link title &amp; URL', 'kepler-wp'),
                        'param_name' => 'kepler_link',
                        'description' => esc_html__('Specify an optional link', 'kepler-wp')
                    ),
                    array(
                        'type' => 'css_editor',
                        'heading' => esc_html__('Css', 'kepler-wp'),
                        'param_name' => 'css',
                        'group' => esc_html__('Design options', 'kepler-wp'),
                    )
                )
            )
    );
}
class WPBakeryShortCode_kepler_twitter_elements extends WPBakeryShortCode {
    
}