<?php

if ( !defined( 'ABSPATH' ) ) {
    exit();
}


// Directs VC to the templates
vc_set_shortcodes_templates_dir( get_template_directory() . '/framework/composer/' );

function kepler_remove_vc_templates ( $data ) {
    return array(); // This will remove all default templates. Basically you should use native PHP functions to modify existing array and then return it.
}

// using wp filter hook to remove shortcodes from the list;
if ( defined( 'WPB_VC_VERSION' ) ) {
    add_filter( 'vc_load_default_templates', 'kepler_remove_vc_templates' );
}
include_once(get_template_directory() . '/framework/composer/components.php');


$font_attributes = array(
            'type' => 'colorpicker',
            'heading' => esc_html__( 'Font color', 'kepler-wp' ),
            'param_name' => 'kepler_row_font_color',
            'description' => esc_html__( 'Select a font color for this row', 'kepler-wp' ),
        );
vc_add_param('vc_row', $font_attributes);

$stretch = array(
            'type' => 'dropdown',
            'heading' => esc_html__( 'Row stretch', 'kepler-wp' ),
            'param_name' => 'full_width',
            'value' => array(
                esc_html__( 'Default', 'kepler-wp' ) => '',
                esc_html__( 'Stretch row', 'kepler-wp' ) => 'stretch_row',
                esc_html__( 'Stretch row and content', 'kepler-wp' ) => 'stretch_row_content_no_spaces'
            ),
            'description' => esc_html__( 'Select stretching options for row and content. Stretched row overlay sidebar and may not work if parent container has overflow: hidden css property.', 'kepler-wp' )
        );
vc_add_param('vc_row', $stretch);

$parallax_attributes = array(
    'type' => 'dropdown',
    'heading' => esc_html__('Parallax', 'kepler-wp'),
    'param_name' => 'parallax',
    'value' => array(
        esc_html__('None', 'kepler-wp') => '',
        esc_html__('Simple', 'kepler-wp') => 'content-moving',
        esc_html__('With fade', 'kepler-wp') => 'content-moving-fade',
        esc_html__('Theme parallax', 'kepler-wp') => 'theme-parallax',
        esc_html__('Theme horizontal parallax', 'kepler-wp') => 'horizontal-parallax',
        esc_html__('Theme animated parallax', 'kepler-wp') => 'animated-parallax',
    ),
    'description' => esc_html__('Select parallax type background for row', 'kepler-wp'),
    'dependency' => array(
        'element' => 'video_bg',
        'is_empty' => true,
    )
);
vc_add_param('vc_row', $parallax_attributes);

// Generates the form inputs related to icomoon icons
function kepler_icomoon_icons_param_settings_field ( $settings, $value ) {
    // Gets the list of icons
    $icons_list = kepler_icons_listing();
    $output = '<div class="kepler_fa_icons_param_block">
            <div class="kepler_icon_container"><span class="' . sanitize_html_class( $value ) . '" id="kepler_selected_icon"></span></div>
            <input id="kepler_icon_input" name="' . esc_attr( $settings ['param_name'] )
            . '" class="icon_input wpb_vc_param_value wpb-textinput '
            . esc_attr( $settings['param_name'] ) . ' ' . esc_attr( $settings['type'] ) . '_field" type="text" value="'
            . esc_attr( $value ) . '" onchange="kepler_selected_icon_display()" />
            <button class="vc_btn vc_btn-primary" onclick="kepler_icon_clear_selection()" >'.esc_html__( 'Clear', 'kepler-wp' ).'</button>
            <br><div id="kepler_icons_list">';
    foreach ( $icons_list as $icon_class ) {
        $output.='<span class="' . $icon_class . '" onclick="kepler_icon_change(this)"></span>';
    }
    $output.='</div></div>';
    return $output;
}

vc_add_shortcode_param( 'kepler_icomoon_icons_param', 'kepler_icomoon_icons_param_settings_field' );

// Generates the form inputs related to font awesome icons
function kepler_fa_icons_param_settings_field ( $settings, $value ) {
    return '<div class="kepler_fa_icons_param_block">
            <i class="' . sanitize_html_class( $value ) . '" id="kepler_selected_icon"></i>
            <input id="kepler_icon_input" name="' . esc_attr( $settings ['param_name'] )
            . '" class="wpb_vc_param_value wpb-textinput '
            . sanitize_html_class( $settings['param_name'] ) . ' ' . sanitize_html_class( $settings['type'] ) . '_field" type="text" value="'
            . esc_attr( $value ) . '" size="10" />
            <br><div id="kepler_icons_list_fa">
            <i class="fa fa-facebook" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-twitter" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-dribbble" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-pinterest" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-google-plus" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-tumblr" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-instagram" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-rss" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-linkedin" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-skype" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-flickr" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-vimeo-square" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-github" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-youtube" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-windows" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-dropbox" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-xing" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-adn" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-android" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-apple" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-behance" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-bitbucket" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-bitcoin" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-codepen" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-css3" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-delicious" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-deviantart" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-digg" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-drupal" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-empire" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-foursquare" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-git" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-gittip" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-hacker-news" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-html5" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-joomla" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-jsfiddle" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-linux" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-maxcdn" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-openid" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-pagelines" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-pied-piper" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-qq" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-rebel" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-reddit" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-renren" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-share" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-slack" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-soundcloud" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-spotify" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-stack-exchange" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-stack-overflow" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-steam" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-stumbleupon" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-tencent-weibo" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-trello" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-vine" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-vk" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-wechat" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-weibo" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-wordpress" onclick="kepler_icon_change(this)"></i>
            <i class="fa fa-yahoo" onclick="kepler_icon_change(this)"></i>
            </div></div>';
}

vc_add_shortcode_param( 'kepler_fa_icons_param', 'kepler_fa_icons_param_settings_field' );

function kepler_icons_listing () {
    return array('ifc-zoom_out',
        'ifc-zoom_in',
        'ifc-zip',
        'ifc-xls',
        'ifc-xlarge_icons',
        'ifc-workstation',
        'ifc-workflow',
        'ifc-word',
        'ifc-windows_client',
        'ifc-wifi_logo',
        'ifc-wifi_direct',
        'ifc-wifi',
        'ifc-whole_hand',
        'ifc-week_view',
        'ifc-wedding_rings',
        'ifc-wedding_photo',
        'ifc-wedding_day',
        'ifc-web_shield',
        'ifc-web_camera',
        'ifc-waypoint_map',
        'ifc-waxing_gibbous',
        'ifc-waxing_crescent',
        'ifc-wav',
        'ifc-water',
        'ifc-watch',
        'ifc-washing_machine',
        'ifc-warning_shield',
        'ifc-waning_gibbous',
        'ifc-waning_crescent',
        'ifc-wallet',
        'ifc-wacom_tablet',
        'ifc-vpn',
        'ifc-volleyball',
        'ifc-voip_gateway',
        'ifc-vkontakte',
        'ifc-visa',
        'ifc-virtual_mashine',
        'ifc-virtual_machine',
        'ifc-video_camera',
        'ifc-vector',
        'ifc-variable',
        'ifc-user_male4',
        'ifc-user_male3',
        'ifc-user_male2',
        'ifc-user_male',
        'ifc-user_female4',
        'ifc-user_female3',
        'ifc-user_female2',
        'ifc-user_female',
        'ifc-USD',
        'ifc-uppercase',
        'ifc-upload2_filled',
        'ifc-upload2',
        'ifc-upload_filled',
        'ifc-upload',
        'ifc-update',
        'ifc-up4',
        'ifc-up3',
        'ifc-up2',
        'ifc-up_right',
        'ifc-up_left',
        'ifc-up',
        'ifc-unlock',
        'ifc-unicast',
        'ifc-undo',
        'ifc-underline',
        'ifc-umbrella_filled',
        'ifc-umbrella',
        'ifc-type',
        'ifc-txt',
        'ifc-two_smartphones',
        'ifc-twitter',
        'ifc-tv_show',
        'ifc-tv',
        'ifc-tumbler',
        'ifc-ttf',
        'ifc-trophy',
        'ifc-treasury_map',
        'ifc-trash2',
        'ifc-trash',
        'ifc-transistor',
        'ifc-torah',
        'ifc-toolbox',
        'ifc-tones',
        'ifc-today',
        'ifc-timezone-12',
        'ifc-timezone-11',
        'ifc-timezone-10',
        'ifc-timezone-9',
        'ifc-timezone-8',
        'ifc-timezone-7',
        'ifc-timezone-6',
        'ifc-timezone-5',
        'ifc-timezone-4',
        'ifc-timezone-3',
        'ifc-timezone-2',
        'ifc-timezone-1',
        'ifc-timezone_utc',
        'ifc-timezone_12',
        'ifc-timezone_11',
        'ifc-timezone_10',
        'ifc-timezone_9',
        'ifc-timezone_8',
        'ifc-timezone_7',
        'ifc-timezone_6',
        'ifc-timezone_5',
        'ifc-timezone_4',
        'ifc-timezone_3',
        'ifc-timezone_2',
        'ifc-timezone_1',
        'ifc-timezone',
        'ifc-timer',
        'ifc-tif',
        'ifc-thumb_up',
        'ifc-thumb_down',
        'ifc-this_way_up',
        'ifc-text_color',
        'ifc-temperature',
        'ifc-tea',
        'ifc-tar',
        'ifc-talk',
        'ifc-tails',
        'ifc-table',
        'ifc-switch_camera_filled',
        'ifc-switch_camera',
        'ifc-switch',
        'ifc-swipe_up',
        'ifc-swipe_right',
        'ifc-swipe_left',
        'ifc-swipe_down',
        'ifc-swimming',
        'ifc-surface',
        'ifc-sun',
        'ifc-summer',
        'ifc-student',
        'ifc-strikethrough',
        'ifc-storm',
        'ifc-stopwatch',
        'ifc-stepper_motor',
        'ifc-stack_of_photos',
        'ifc-stack',
        'ifc-ssd',
        'ifc-speedometer',
        'ifc-speech_bubble',
        'ifc-south_direction',
        'ifc-smartphone_tablet',
        'ifc-small_lens',
        'ifc-small_icons',
        'ifc-slr_small_lens',
        'ifc-slr_large_lens',
        'ifc-slr_camera2_filled',
        'ifc-slr_camera2',
        'ifc-slr_camera_body',
        'ifc-slr_camera',
        'ifc-slr_back_side',
        'ifc-sling_here',
        'ifc-sleet',
        'ifc-slave',
        'ifc-skype',
        'ifc-skip_to_start',
        'ifc-shuffle',
        'ifc-shopping_cart_loaded',
        'ifc-shopping_cart_empty',
        'ifc-shopping_basket',
        'ifc-shop',
        'ifc-shield',
        'ifc-shared',
        'ifc-settings3',
        'ifc-settings2',
        'ifc-settings',
        'ifc-server',
        'ifc-sent',
        'ifc-sensor',
        'ifc-sell',
        'ifc-SEK',
        'ifc-security_ssl',
        'ifc-security_checked',
        'ifc-security_aes',
        'ifc-search',
        'ifc-sea_waves',
        'ifc-scrolling',
        'ifc-screwdriver',
        'ifc-scales_of_Balance',
        'ifc-sale',
        'ifc-sagittarius',
        'ifc-safari',
        'ifc-sad',
        'ifc-running_rabbit',
        'ifc-running',
        'ifc-run_command',
        'ifc-rugby',
        'ifc-rucksach',
        'ifc-rss',
        'ifc-router',
        'ifc-rotation_cw',
        'ifc-rotation_ccw',
        'ifc-rotate_to_portrait',
        'ifc-rotate_to_landscape',
        'ifc-rotate_camera',
        'ifc-rook',
        'ifc-right3',
        'ifc-right2',
        'ifc-right_click',
        'ifc-right',
        'ifc-rfid_tag',
        'ifc-rfid_signal',
        'ifc-rfid_sensor',
        'ifc-rewind',
        'ifc-resize',
        'ifc-replay',
        'ifc-repeat',
        'ifc-rename',
        'ifc-remove_user',
        'ifc-remove_image',
        'ifc-remote_working',
        'ifc-reload',
        'ifc-relay',
        'ifc-register_editor',
        'ifc-redo',
        'ifc-red_hat',
        'ifc-recycle_sign_filled',
        'ifc-recycle_sign',
        'ifc-read_message',
        'ifc-rar',
        'ifc-radio_tower',
        'ifc-radar_plot',
        'ifc-rack',
        'ifc-quote',
        'ifc-puzzle',
        'ifc-put_out',
        'ifc-put_in_motion',
        'ifc-put_in',
        'ifc-publisher',
        'ifc-psd',
        'ifc-processor',
        'ifc-private2',
        'ifc-print',
        'ifc-price_tag_usd',
        'ifc-price_tag_pound',
        'ifc-price_tag_euro',
        'ifc-price_tag',
        'ifc-pressure',
        'ifc-presentation',
        'ifc-power_point',
        'ifc-positive_dynamic',
        'ifc-portrait_mode',
        'ifc-popular_topic',
        'ifc-polyline',
        'ifc-polygone',
        'ifc-polygon',
        'ifc-poll_topic',
        'ifc-png',
        'ifc-plus',
        'ifc-plugin',
        'ifc-pliers',
        'ifc-play',
        'ifc-plasmid',
        'ifc-piston',
        'ifc-pinterest',
        'ifc-pinch',
        'ifc-pin',
        'ifc-pill',
        'ifc-pie_chart',
        'ifc-picture',
        'ifc-pickup',
        'ifc-photo',
        'ifc-phone2',
        'ifc-phone1',
        'ifc-perforator',
        'ifc-pencil_sharpener',
        'ifc-pen',
        'ifc-pdf',
        'ifc-pawn',
        'ifc-pause',
        'ifc-password',
        'ifc-passenger',
        'ifc-paper_clip',
        'ifc-paper_clamp',
        'ifc-panorama',
        'ifc-paint_bucket',
        'ifc-paint_basket',
        'ifc-pain_brush',
        'ifc-overhead_crane',
        'ifc-outlook',
        'ifc-outline',
        'ifc-outgoing_data',
        'ifc-otf',
        'ifc-osm',
        'ifc-origami',
        'ifc-opera',
        'ifc-opened_folder',
        'ifc-open_in_browser',
        'ifc-online',
        'ifc-one_note',
        'ifc-one_finger',
        'ifc-old_time_camera',
        'ifc-ogg',
        'ifc-office_lamp',
        'ifc-numerical_sorting_21',
        'ifc-north_direction',
        'ifc-night_vision',
        'ifc-new_moon',
        'ifc-neutral_decision',
        'ifc-negative_dynamic',
        'ifc-near_me',
        'ifc-nas',
        'ifc-mute',
        'ifc-musical',
        'ifc-music_video',
        'ifc-music_record',
        'ifc-music',
        'ifc-multiple_smartphones',
        'ifc-multiple_inputs',
        'ifc-multiple_devices',
        'ifc-multiple_cameras',
        'ifc-multicast',
        'ifc-mpg',
        'ifc-mp3',
        'ifc-movie',
        'ifc-moved_topic',
        'ifc-move_by_trolley',
        'ifc-mov',
        'ifc-mouse_trap',
        'ifc-mouse',
        'ifc-month_view',
        'ifc-money_box',
        'ifc-money_bag',
        'ifc-money',
        'ifc-mobile_home',
        'ifc-minus',
        'ifc-mind_map',
        'ifc-micro2',
        'ifc-micro',
        'ifc-message',
        'ifc-mess_tin',
        'ifc-menu',
        'ifc-memory_module',
        'ifc-megaphone2',
        'ifc-megaphone',
        'ifc-medium_volume',
        'ifc-medium_icons',
        'ifc-medium_battery',
        'ifc-math',
        'ifc-matches',
        'ifc-mastercard',
        'ifc-map_marker',
        'ifc-map_editing',
        'ifc-map',
        'ifc-male',
        'ifc-magnet',
        'ifc-mac_client',
        'ifc-luggage_trolley',
        'ifc-lowercase',
        'ifc-low_volume',
        'ifc-low_battery',
        'ifc-lol',
        'ifc-log_cabine',
        'ifc-lock_portrait',
        'ifc-lock_landscape',
        'ifc-lock',
        'ifc-livingroom',
        'ifc-little_snow',
        'ifc-little_rain',
        'ifc-literature',
        'ifc-list',
        'ifc-linux_client',
        'ifc-linkedin',
        'ifc-link',
        'ifc-line_width',
        'ifc-line_chart',
        'ifc-line',
        'ifc-like',
        'ifc-lift_cart_here',
        'ifc-libra',
        'ifc-left3',
        'ifc-left2',
        'ifc-left_click',
        'ifc-left',
        'ifc-lcd',
        'ifc-layers',
        'ifc-last_quarter',
        'ifc-laser_beam',
        'ifc-large_lens',
        'ifc-large_icons',
        'ifc-laptop',
        'ifc-lantern',
        'ifc-lamp',
        'ifc-knight',
        'ifc-knife',
        'ifc-kmz',
        'ifc-kml',
        'ifc-king',
        'ifc-keyboard',
        'ifc-key',
        'ifc-keep_dry',
        'ifc-jpg',
        'ifc-joystick',
        'ifc-jingle_bell',
        'ifc-jcb',
        'ifc-java_coffee_cup_logo',
        'ifc-iphone',
        'ifc-ipad',
        'ifc-ip_address',
        'ifc-invisible',
        'ifc-internet_explorer',
        'ifc-internal',
        'ifc-integrated_webcam',
        'ifc-integrated_circuit',
        'ifc-instagram',
        'ifc-infrared_beam_sensor',
        'ifc-infrared_beam_sending',
        'ifc-infrared',
        'ifc-informatics',
        'ifc-info',
        'ifc-increase_font',
        'ifc-incoming_data',
        'ifc-incendiary_grenade',
        'ifc-inbox',
        'ifc-in_love',
        'ifc-import',
        'ifc-idea',
        'ifc-icq',
        'ifc-hydroelectric',
        'ifc-humidity',
        'ifc-humburger',
        'ifc-human_footprints',
        'ifc-hub',
        'ifc-html',
        'ifc-hot_dog',
        'ifc-hot_chocolate',
        'ifc-horseshoe',
        'ifc-home',
        'ifc-history',
        'ifc-high_volume',
        'ifc-high_battery',
        'ifc-hex_burner',
        'ifc-herald_trumpet',
        'ifc-help2',
        'ifc-help',
        'ifc-helicopter',
        'ifc-heat_map',
        'ifc-heart_monitor',
        'ifc-headset',
        'ifc-headphones',
        'ifc-handle_with_care',
        'ifc-hand_planting',
        'ifc-hand_palm_scan',
        'ifc-hand',
        'ifc-hammer',
        'ifc-group',
        'ifc-grass',
        'ifc-gpx',
        'ifc-gps_receiving',
        'ifc-gps_disconnected',
        'ifc-google_plus',
        'ifc-good_decision',
        'ifc-gis',
        'ifc-gift',
        'ifc-gif',
        'ifc-geocaching',
        'ifc-geo_fence',
        'ifc-generic_text',
        'ifc-generic_sorting2',
        'ifc-generic_sorting',
        'ifc-genealogy',
        'ifc-genderqueer',
        'ifc-GBP',
        'ifc-gas2',
        'ifc-gantt_chart',
        'ifc-gallery',
        'ifc-gaiters',
        'ifc-fully_charged_battery',
        'ifc-full_moon',
        'ifc-fridge',
        'ifc-french_fries',
        'ifc-four_fingers',
        'ifc-forward2',
        'ifc-forward',
        'ifc-fork_truck',
        'ifc-fork',
        'ifc-football2',
        'ifc-football',
        'ifc-food',
        'ifc-folder',
        'ifc-fog_night',
        'ifc-fog_day',
        'ifc-flv',
        'ifc-flow_chart',
        'ifc-flip_vertical',
        'ifc-flip_horizontal',
        'ifc-flip_flops',
        'ifc-flash_light',
        'ifc-flag2',
        'ifc-flag',
        'ifc-first_quarter',
        'ifc-firefox',
        'ifc-find_user',
        'ifc-filter',
        'ifc-film_reel',
        'ifc-filled_box',
        'ifc-fb2',
        'ifc-fast_forward',
        'ifc-fantasy',
        'ifc-facebook',
        'ifc-external_link',
        'ifc-external',
        'ifc-export',
        'ifc-expensive',
        'ifc-expand',
        'ifc-exit',
        'ifc-exe',
        'ifc-excel',
        'ifc-EUR',
        'ifc-error',
        'ifc-eraser',
        'ifc-epub',
        'ifc-eps',
        'ifc-enter',
        'ifc-engineering',
        'ifc-end',
        'ifc-email',
        'ifc-ellipse',
        'ifc-electronics',
        'ifc-eggs',
        'ifc-edit_user',
        'ifc-edit_image',
        'ifc-edit',
        'ifc-east_direction',
        'ifc-earth_element',
        'ifc-dribbble',
        'ifc-drafting_compass',
        'ifc-downpour',
        'ifc-download2_filled',
        'ifc-download2',
        'ifc-download_filled',
        'ifc-download',
        'ifc-down4',
        'ifc-down2',
        'ifc-down_right',
        'ifc-down_left',
        'ifc-down',
        'ifc-double_tap',
        'ifc-donut_chart',
        'ifc-domain',
        'ifc-documentary',
        'ifc-document',
        'ifc-doctor_suitecase',
        'ifc-doctor',
        'ifc-doc',
        'ifc-do_not_tilt',
        'ifc-do_not_stack',
        'ifc-do_not_expose_to_sunlight',
        'ifc-do_not_drop',
        'ifc-dna_helix',
        'ifc-directions',
        'ifc-diamonds',
        'ifc-dharmacakra',
        'ifc-design',
        'ifc-delete_sign',
        'ifc-delete_shield',
        'ifc-delete_message',
        'ifc-define_location',
        'ifc-decrease_font',
        'ifc-day_view',
        'ifc-date_to',
        'ifc-date_from',
        'ifc-database_protection',
        'ifc-database_encryption',
        'ifc-database_backup',
        'ifc-database',
        'ifc-data_in_both_directions',
        'ifc-cymbals',
        'ifc-cut',
        'ifc-currency',
        'ifc-csv',
        'ifc-css',
        'ifc-crystal_ball',
        'ifc-crop',
        'ifc-creek',
        'ifc-coral',
        'ifc-copy_link',
        'ifc-copy',
        'ifc-control_panel',
        'ifc-content',
        'ifc-contacts',
        'ifc-contact_card',
        'ifc-construction_worker',
        'ifc-console',
        'ifc-connected_no_data',
        'ifc-compost_heap',
        'ifc-compass2',
        'ifc-compas',
        'ifc-command_line',
        'ifc-combo_chart',
        'ifc-comb',
        'ifc-color_dropper',
        'ifc-collect',
        'ifc-collapse',
        'ifc-coffee',
        'ifc-code',
        'ifc-coctail',
        'ifc-clouds',
        'ifc-cloud_storage',
        'ifc-close_up_mode',
        'ifc-close',
        'ifc-clock',
        'ifc-clipperboard',
        'ifc-clear_shopping_cart',
        'ifc-circuit',
        'ifc-chrome',
        'ifc-christmas_star',
        'ifc-christmas_gift',
        'ifc-chisel_tip_marker',
        'ifc-child_new_post',
        'ifc-checkmark',
        'ifc-checked_user',
        'ifc-cheap',
        'ifc-charge_battery',
        'ifc-change_user',
        'ifc-centre_of_gravity',
        'ifc-center_direction',
        'ifc-cash_receiving',
        'ifc-carabiner',
        'ifc-car_battery',
        'ifc-capacitor',
        'ifc-cannon',
        'ifc-cancel',
        'ifc-camping_tent',
        'ifc-camera_identification',
        'ifc-camera_addon_identification',
        'ifc-camera_addon',
        'ifc-camcoder_pro',
        'ifc-camcoder',
        'ifc-calendar',
        'ifc-CAD',
        'ifc-cable_release',
        'ifc-business',
        'ifc-bus',
        'ifc-bungalow',
        'ifc-bunch_ingredients',
        'ifc-broadcasting',
        'ifc-briefcase',
        'ifc-brandenburg_gate',
        'ifc-brain_filled',
        'ifc-brain',
        'ifc-box2',
        'ifc-box',
        'ifc-border_color',
        'ifc-bookmark',
        'ifc-blur',
        'ifc-bluetooth2',
        'ifc-bluetooth',
        'ifc-birthday_cake',
        'ifc-birthday',
        'ifc-biotech',
        'ifc-barbers_scissors',
        'ifc-bar_chart',
        'ifc-banknotes',
        'ifc-bandage',
        'ifc-ball_point_pen',
        'ifc-bad_decision',
        'ifc-background_color',
        'ifc-back',
        'ifc-avi',
        'ifc-average',
        'ifc-audio_wave2',
        'ifc-audio_wave',
        'ifc-asc',
        'ifc-armchair',
        'ifc-area_chart',
        'ifc-archive',
        'ifc-aquarius',
        'ifc-application_shield',
        'ifc-apartment',
        'ifc-antiseptic_cream',
        'ifc-android_os',
        'ifc-ancore',
        'ifc-anchor',
        'ifc-ammo_tin',
        'ifc-amex',
        'ifc-ambulance',
        'ifc-alphabetical_sorting_za',
        'ifc-alphabetical_sorting_az',
        'ifc-align_right',
        'ifc-align_left',
        'ifc-align_justify',
        'ifc-align_center',
        'ifc-alarm_clock',
        'ifc-airplane_take_off',
        'ifc-airplane',
        'ifc-ai',
        'ifc-age',
        'ifc-adventures',
        'ifc-adobe_photoshop',
        'ifc-adobe_indesign',
        'ifc-adobe_illustrator',
        'ifc-adobe_flash',
        'ifc-adobe_fireworks',
        'ifc-adobe_dreamweaver',
        'ifc-adobe_bridge',
        'ifc-administrative_tools',
        'ifc-add_user',
        'ifc-add_image',
        'ifc-add_database',
        'ifc-zip2',
        'ifc-f_tap',
        'ifc-f_swipe_up',
        'ifc-f_swipe_right',
        'ifc-f_swipe_left',
        'ifc-f_swipe_down',
        'ifc-f_double_tap');
}
