<?php

if ( !defined( 'ABSPATH' ) ) {
    exit();
}
// Meta box structure for custom sidebars field in the edit page section of the admin
$kepler_meta_box = array(
    'id' => 'kepler-page-sidebar',
    'title' => esc_html__( 'Page Layout and Sidebar Manager', 'kepler-wp' ),
    'page' => 'page',
    'context' => 'normal',
    'priority' => 'high',
    'fields' => array(
        // Sidebar positioning options
        array(
            'name' => esc_html__( 'Page Layout', 'kepler-wp' ),
            'id' => 'kepler_sidebar_position',
            'type' => 'radio',
            'options' => array(
                array('name' => 'Left', 'value' => 'left'),
                array('name' => 'None', 'value' => 'none'),
                array('name' => 'Right', 'value' => 'right')
            )
        ),
        // Sidebars list
        array(
            'name' => esc_html__( 'Sidebar', 'kepler-wp' ),
            'id' => 'kepler_sidebar_source',
            'type' => 'select'
        )
    )
);

add_action( 'admin_menu', 'kepler_sidebar_add_box' );

// Add the meta box
function kepler_sidebar_add_box () {
    global $kepler_meta_box;
    add_meta_box( $kepler_meta_box['id'], $kepler_meta_box['title'], 'kepler_sidebar_show_box', $kepler_meta_box['page'], $kepler_meta_box['context'], $kepler_meta_box['priority'] );
    if ( defined( 'ERP_PATH' ) ) {
        add_meta_box( $kepler_meta_box['id'], $kepler_meta_box['title'], 'kepler_sidebar_show_box', 'erp-portfolio', $kepler_meta_box['context'], $kepler_meta_box['priority'] );
    }
    if (  class_exists( 'woocommerce' ) ) {
        add_meta_box( $kepler_meta_box['id'], $kepler_meta_box['title'], 'kepler_sidebar_show_box', 'product', $kepler_meta_box['context'], $kepler_meta_box['priority'] );
    }
}

// Callback function to show fields in meta box
function kepler_sidebar_show_box () {
    global $kepler_meta_box, $post;
    // Use nonce for verification

    echo '<input type="hidden" name="kepler_sidebar_meta_box_nonce" value="' . esc_attr( wp_create_nonce( get_template_directory() ) ) . '" />';
    echo '<table class="form-table">';
    foreach ( $kepler_meta_box['fields'] as $field ) {
        // Get current post meta data
        $meta = get_post_meta( $post->ID, $field['id'], true );
        echo '<tr>',
        '<th style="width:20%"><label for="', esc_attr( $field['id'] ), '">', esc_html( $field['name'] ), '</label></th>',
        '<td>';
        switch ( $field['type'] ) {
            case 'radio':
                echo '<div>';
                foreach ( $field['options'] as $option ) {
                    echo '<div class="sidebar_icon_radio">';
                    $check_title = '';
                    switch ( $option['value'] ) {
                        case 'left':
                            echo '<img title="' . esc_html__( 'Sidebar on the left', 'kepler-wp' ) . '" src="' . esc_url( get_template_directory_uri() ) . '/framework/admin/images/icon_sidebar_left.png" alt="sidebar left">';
                            break;
                        case 'none':
                            echo '<img title="' . esc_html__( 'No Sidebar', 'kepler-wp' ) . '" src="' . esc_url( get_template_directory_uri() ) . '/framework/admin/images/icon_sidebar_none.png" alt="sidebar none">';
                            break;
                        case 'right':
                            echo '<img title="' . esc_html__( 'Sidebar on the right', 'kepler-wp' ) . '" src="' . esc_url( get_template_directory_uri() ) . '/framework/admin/images/icon_sidebar_right.png" alt="sidebar right">';
                            break;
                    }
                    // Prepare the default option
                    if ( $meta == null && $option['value'] == 'none' ) {
                        $default_check = 'checked="checked"';
                    } else {
                        $default_check = '';
                    }
                    echo '<br><div class="sidebar_position_option_style">'
                    . '<input title="' . esc_html__( 'No Sidebar', 'kepler-wp' ) . '" type="radio" name="', esc_attr( $field['id'] ), '" '
                    . 'value="', esc_attr( $option['value'] ), '"', $meta == $option['value'] ? ' checked="checked"' : '', ' ' . esc_attr( $default_check ) . ' /></div>';
                    echo '</div>';
                }
                echo '</div>';
                echo '<br class="clear_kepler"><br><p>' . esc_html__( 'Select if the page should have a sidebar and how it should be positioned', 'kepler-wp' ) . '</p>';
                break;
            case 'select':
                global $wp_registered_sidebars;
                echo '<div>';
                echo '<select name="', esc_attr( $field['id'] ), '" id="', sanitize_html_class( $field['id'] ), '">';
                foreach ( $wp_registered_sidebars as $sidebar ) {
                    $check_sidebar = explode( 'kepler-footer-', $sidebar['id'] );
                    if ( count( $check_sidebar ) == 1 ) {
                        echo '<option ', $meta == $sidebar['id'] ? ' selected="selected"' : '', ' value="', esc_attr($sidebar['id']), '">', esc_html($sidebar['name']), '</option>';
                    }
                }
                echo '</select>';
                echo '</div>';
                echo '<br class="clear_kepler"><p>' . esc_html__( 'Select the sidebar that should be used. You can create additional sidebars in the Widgets page.', 'kepler-wp' ) . '</p>';
                break;
        }
        echo '</td><td>',
        '</td></tr>';
    }
    echo '</table>';
}

add_action( 'save_post', 'kepler_save_sidebar_data' );

// Save data from meta box
function kepler_save_sidebar_data ( $post_id ) {
    global $kepler_meta_box;
    if ( isset( $_POST['kepler_sidebar_meta_box_nonce'] ) ) {
        // Verify nonce
        if ( !wp_verify_nonce( $_POST['kepler_sidebar_meta_box_nonce'], get_template_directory() ) ) {
            return $post_id;
        }
        // Check autosave
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
            return $post_id;
        }
        // Check permissions
        if ( 'page' == $_POST['post_type'] ) {
            if ( !current_user_can( 'edit_page', $post_id ) ) {
                return $post_id;
            }
        } elseif ( !current_user_can( 'edit_post', $post_id ) ) {
            return $post_id;
        }
        // Populates the meta box fields with the appropriate data
        foreach ( $kepler_meta_box['fields'] as $field ) {
            $old = get_post_meta( $post_id, $field['id'], true );
            $new = $_POST[$field['id']];
            if ( $new && $new != $old ) {
                update_post_meta( absint( $post_id ), sanitize_text_field( $field['id'] ), sanitize_text_field( $new ) );
            } elseif ( '' == $new && $old ) {
                delete_post_meta( absint( $post_id ), sanitize_text_field( $field['id'] ), sanitize_text_field( $old ) );
            }
        }
    }
}

$kepler_metabox_page_header = array(
    'id' => 'kepler-page-header',
    'title' => esc_html__('Page Header', 'kepler-wp'),
    'context' => 'normal',
    'priority' => 'high',
    'fields' => array(
        array(
            'name' => esc_html__('Header Config', 'kepler-wp'),
            'id' => 'kepler_header_toggle',
            'type' => 'toggle',
            'options' => array(
                array('name' => 'Enable', 'value' => 'Enable'),
                array('name' => 'Disable', 'value' => 'Disable')
            )
        ),
        array(
            'name' => esc_html__('Page header title', 'kepler-wp'),
            'id' => 'kepler_header_title',
            'type' => 'text'
        ),
        array(
            'name' => esc_html__('Font color', 'kepler-wp'),
            'id' => 'kepler_header_font_color',
            'type' => 'colorpicker',
            'default' => ''
        ),
        array(
            'name' => esc_html__('Background image', 'kepler-wp'),
            'id' => 'kepler_header_image',
            'type' => 'image'
        )
    )
);

add_action('admin_menu', 'kepler_page_header_add_box');

// Add the meta box
function kepler_page_header_add_box() {
    
    global $kepler_metabox_page_header;
    add_meta_box($kepler_metabox_page_header['id'], $kepler_metabox_page_header['title'], 'kepler_page_header_show_box', 'page', $kepler_metabox_page_header['context'], $kepler_metabox_page_header['priority']);
    if ( defined( 'ERP_PATH' ) ) {
        add_meta_box( $kepler_metabox_page_header['id'], $kepler_metabox_page_header['title'], 'kepler_page_header_show_box', 'erp-portfolio', $kepler_metabox_page_header['context'], $kepler_metabox_page_header['priority'] );
    }
    if ( class_exists( 'woocommerce' ) ) {
        add_meta_box( $kepler_metabox_page_header['id'], $kepler_metabox_page_header['title'], 'kepler_page_header_show_box', 'product', $kepler_metabox_page_header['context'], $kepler_metabox_page_header['priority'] );
    }
}

// Callback function to show fields in meta box
function kepler_page_header_show_box() {
    global $kepler_metabox_page_header, $post;
    // Use nonce for verification
    echo '<input type="hidden" name="kepler_page_header_meta_box_nonce" value="', wp_create_nonce(get_template_directory()), '" />';
    echo '<table id="kepler_header_options_table" class="form-table">';
    foreach ($kepler_metabox_page_header['fields'] as $field) {
        // Get current post meta data
        $meta = get_post_meta($post->ID, $field['id'], true);
        echo '<tr';
        if ($field['id'] == 'kepler_header_style') {
            echo ' id="kepler_style_container"';
        }
        echo '><th><label for="', esc_attr($field['id']), '">', esc_html($field['name']), '</label></th>',
        '<td>';
        switch ($field['type']) {
            case 'toggle':
                echo '<div>';
                foreach ($field['options'] as $option) {
                    // Prepare the default option
                    if ($meta == null && ($option['value'] == 'Enable' || $option['value'] == 'on')) {
                        $default_check = 'checked="checked"';
                    } else {
                        $default_check = '';
                    }
                    echo ' <input type="radio" id="toggle-' . sanitize_html_class($option['value']) . '" class="toggle toggle-' . sanitize_html_class($option['value']) . '" name="', esc_attr($field['id']), '" '
                    . 'value="', esc_attr($option['value']), '"', $meta == $option['value'] ? ' checked="checked"' : '', ' ' . $default_check . ' ', $field['id'] == 'kepler_style_toggle' ? 'onchange="kepler_style_select()"' : 'onclick="kepler_header_override()"', ' />'
                    . '<label for="toggle-' . esc_attr($option['value']) . '">' . esc_html($option['name']) . '</label>';
                }
                echo '</div>';
                break;
            case 'text':
                echo '<input type="text" name="' . esc_attr($field['id']) . '" id="' . esc_attr($field['id']) . '" value="' . esc_attr($meta) . '" size="30" /><br>';
                break;
            case 'colorpicker':
                echo '<div class="kepler_color_preview" id="kepler_color_preview_id" style="background-color:' . esc_attr($meta) . ';"></div><div id="kepler_color_preview_container_id">';
                echo '<input type="text" name="' . esc_attr($field['id']) . '" id="' . esc_attr($field['id']) . '" value="' . esc_attr($meta) . '" class="custom_header_color" data-default-color="#fff" /></div>';
                break;
            case 'checkbox':
                if ($meta == $field['value']) {
                    $default_check = 'checked="checked"';
                } else {
                    $default_check = '';
                }
                echo '<input type="checkbox" name="' . esc_attr($field['id']) . '" id="' . esc_attr($field['id']) . '" value="'.esc_attr($field['value']).'" ' . esc_html($default_check) . ' />' . esc_html__('Enable', 'kepler-wp') . '<br>';
                echo '<br class="clear_kepler"><p>' . esc_html($field['description']) . '</p>';
                break;  
            case 'image':
                echo '<span class="custom_default_image" style="display:none"></span>';
                 $image_none = get_template_directory_uri() . "/framework/admin/images/image-none.png";
                if ( $meta ) {
                    $image = wp_get_attachment_image_src( $meta, 'medium' );
                    $image = $image[0];
                } else {
                    $image = $image_none;
                }
                echo '<input name="' . esc_attr( $field['id'] ) . '" id="' . esc_attr( $field['id'] ) . '_upload_input" type="hidden" class="custom_upload_image" value="' . esc_attr( $meta ) . '" />
                <img src="' . esc_url( $image ) . '" class="custom_preview_image" id="' . esc_attr( $field['id'] ) . '_preview_image" alt="" /><br />
                    <input id="' . esc_attr( $field['id'] ) . '_trigger" class="custom_upload_image_button button kepler_custom_image_upload_trigger" name="custom_upload_image_button" type="button" value="' . esc_html__( 'Choose Image', 'kepler-wp' ) . '" onclick="kepler_upload_trigger(\'' . $field['id'] . '\')"/>
                    <input id="' . esc_attr( $field['id'] ) . '_upload_input_clear" class="button kepler_clear_img custom_upload_image_button" value="' . esc_html__( 'Remove Image', 'kepler-wp' ) . '" type="button" onclick="kepler_clear_image_trigger(\'' . $field['id'] . '\',\'' . $image_none . '\')">';

                echo '<br class="clear_kepler"><p>' . esc_html__( 'Select a background image', 'kepler-wp' ) . '</p>';

                break;
        }
        echo '</td><td>',
        '</td></tr>';
    }
    echo '</table>';
}

add_action('save_post', 'kepler_save_page_header_data');

// Save data from meta box
function kepler_save_page_header_data($post_id) {
    global $kepler_metabox_page_header;
    if (isset($_POST['kepler_page_header_meta_box_nonce'])) {
        // Verify nonce
        if (!wp_verify_nonce($_POST['kepler_page_header_meta_box_nonce'], get_template_directory())) {
            return $post_id;
        }
        // Check autosave
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return $post_id;
        }
        // Check permissions
        if ('page' == $_POST['post_type']) {
            if (!current_user_can('edit_page', $post_id)) {
                return $post_id;
            }
        } elseif (!current_user_can('edit_post', $post_id)) {
            return $post_id;
        }
        // Populates the meta box fields with the appropriate data
        foreach ($kepler_metabox_page_header['fields'] as $field) {
            $old = get_post_meta(absint($post_id), sanitize_text_field($field['id']), true);
            if (isset($_POST[$field['id']])) {
                $new = $_POST[$field['id']];
                if ($new && $new != $old) {
                    update_post_meta(absint($post_id), sanitize_text_field($field['id']), sanitize_text_field($new));
                } elseif ('' == $new && $old) {
                    delete_post_meta(absint($post_id), sanitize_text_field($field['id']), sanitize_text_field($old));
                }
            } else {
                delete_post_meta(absint($post_id), sanitize_text_field($field['id']), sanitize_text_field($old));
            }
        }
    }
}

// Check autosave
if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
    return $post_id;
}