<?php

if (!defined('ABSPATH')) {
    exit();
}

function kepler_is_edit_page($new_edit = null) {
    global $pagenow;
    //make sure we are on the backend
    if (!is_admin()) {
        return false;
    }

    if ($new_edit == "edit") {
        return in_array($pagenow, array('post.php',));
    } else if ($new_edit == "new") {//check for new post page
        return in_array($pagenow, array('post-new.php'));
    } else {//check for either new or edit
        return in_array($pagenow, array('post.php', 'post-new.php'));
    }
}

// CSS and JS files for the site
function kepler_front_styles_scripts() {

    wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/fonts/fontawesome/font-awesome.min.css');

    wp_enqueue_style('iconfontcustom', get_template_directory_uri() . '/assets/fonts/iconfontcustom/icon-font-custom.css');

    wp_enqueue_script('gmap-sensor', '//maps.google.com/maps/api/js?sensor=false', array('jquery'), false, true);

    wp_enqueue_script('kepler-scripts-js', get_template_directory_uri() . '/assets/js/scripts.js', array('jquery'), false, true);

    // custom scripts
    wp_register_script('kepler-main-js', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), false, true);

    $kepler_sticky_toggle = false;
    global $kepler_theme_options;
    if (isset($kepler_theme_options['kepler-header-stickyheader-toggle'])) {
        if ($kepler_theme_options['kepler-header-stickyheader-toggle'] == 1) {
            $kepler_sticky_toggle = true;
        }
    }

    wp_localize_script('kepler-main-js', 'kepler_sticky', array('kepler_sticky_toggle' => $kepler_sticky_toggle));

    wp_enqueue_script('kepler-main-js');

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }

    if (isset($kepler_theme_options['kepler-smoothscroll-toggle'])) {
        if ($kepler_theme_options['kepler-smoothscroll-toggle'] == 1) {
            wp_enqueue_script('kepler-smoothscroll-js', get_template_directory_uri() . '/assets/vendors/smoothscroll/smoothscroll.js', array('jquery'), false, true);
        }
    }

    wp_enqueue_style('kepler-style-css', get_template_directory_uri() . '/style.css');

    wp_enqueue_style('kepler-fonts', kepler_fonts_url(), array(), null);
}

if (!is_admin()) {
    add_action('wp_enqueue_scripts', 'kepler_front_styles_scripts');
}

function kepler_custom_header_fonts() {
    wp_enqueue_style('kepler-fonts', kepler_fonts_url(), array(), null);
}

add_action('admin_print_styles-appearance_page_custom-header', 'kepler_custom_header_fonts');

function kepler_fonts_url() {
    $fonts_url = '';

    /* Translators: If there are characters in your language that are not
     * supported by Lora, translate this to 'off'. Do not translate
     * into your own language.
     */
    $raleway = esc_html_x('on', 'Raleway font: on or off', 'kepler-wp');

    if ('off' !== $raleway) {
        $font_familly = 'Raleway:400,500,700';

        $query_args = array(
            'family' => urlencode($font_familly),
        );

        $fonts_url = add_query_arg($query_args, 'fonts.googleapis.com/css');
    }

    return esc_url_raw($fonts_url);
}

// ENQUEUE SCRIPTS AND STYLES
// CSS and JS for admin panels
function kepler_admin_scripts_and_styles() {
    if (is_admin()) {
        wp_enqueue_media();
        global $typenow;
        global $pagenow;
        if (defined('ERP_PATH')) {
            $erp_slug = 'erp-portfolio';
        } else {
            $erp_slug = false;
        }
        wp_enqueue_script('wp-link');
        if (kepler_is_edit_page() && $erp_slug == $typenow || kepler_is_edit_page() || $pagenow == "nav-menus.php" || $pagenow == 'admin.php' || $pagenow == "widgets.php") {

            wp_enqueue_style('wp-color-picker');
            wp_enqueue_script('wp-color-picker');

            wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/fonts/fontawesome/font-awesome.min.css');

            wp_enqueue_style('iconfontcustom', get_template_directory_uri() . '/assets/fonts/iconfontcustom/icon-font-custom.css');

            wp_enqueue_script('kepler-functions-js', get_template_directory_uri() . '/framework/admin/js/functions.js', array('jquery', 'media-upload'), false, true);
            wp_localize_script('kepler-functions-js', 'kepler_ajax', array('kepler_widget_form_nonce' => wp_create_nonce('kepler_widget_form_ajax'), 'ajaxurl' => admin_url('admin-ajax.php')));
        }
        wp_enqueue_style('kepler-styles-css', get_template_directory_uri() . '/framework/admin/css/styles.css');
    }
}

add_action('admin_enqueue_scripts', 'kepler_admin_scripts_and_styles');


// Set up the content width value based on the theme's design.
if (!isset($content_width)) {
    $content_width = 1170;
}

if (!function_exists('kepler_theme_config')) {

    function kepler_theme_config() {
        add_theme_support('post-thumbnails');
        set_post_thumbnail_size(1140, 0);
        // Crops the uploaded images to certain sizes used for different components and elements
        if (function_exists('add_image_size')) {
            add_image_size('kepler_team_size', 360, 360, true);
            add_image_size('kepler_testimonial_size', 95, 95, true);
        }

        add_theme_support('menus');
        register_nav_menu('kepler-main-nav-menu', esc_html__('Kepler Menu', 'kepler-wp'));

        // translation file
        // Localization Support
        load_theme_textdomain('kepler-wp', get_template_directory() . '/languages');

        $locale = get_locale();
        $locale_file = get_template_directory() . "/languages/$locale.php";
        if (is_readable($locale_file)) {
            require_once($locale_file);
        }
        // Add RSS feed links to <head> for posts and comments.
        add_theme_support('automatic-feed-links');

        add_theme_support('title-tag');

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
        ));

        // Allows to link a custom stylesheet file to the TinyMCE visual editor
        add_editor_style(get_template_directory() . '/assets/css/lists.css');

        // Add support for featured content.
        add_theme_support('featured-content', array(
            'featured_content_filter' => 'kepler_get_featured_content',
            'max_posts' => 6,
        ));

        add_theme_support('post-formats', array('video', 'audio'));

        add_theme_support('woocommerce');
    }

}

add_action('after_setup_theme', 'kepler_theme_config');

function kepler_custom_wp_title($title, $sep) {
    global $paged, $page;

    if (is_feed()) {
        return $title;
    } // end if
    // Add the site name.
    $title = get_bloginfo('name');
    $sep = '-';
    // Add the site description for the home/front page.
    $site_description = get_bloginfo('description', 'display');
    if ($site_description && ( is_home() || is_front_page() )) {
        $title = "$title $sep $site_description";
    } else if (is_search()) {
        $title = esc_html__('Search', 'kepler-wp') . " $sep $title";
    } else if (is_tag()) {
        $title = esc_html__('Tag', 'kepler-wp') . " $sep $title";
    } else if (is_category()) {
        $title = esc_html__('Category', 'kepler-wp') . " $sep $title";
    } else if (is_tax()) {
        $title = esc_html__('Taxonomy', 'kepler-wp') . " $sep $title";
    } else if (is_archive()) {
        $title = esc_html__('Archive', 'kepler-wp') . " $sep $title";
    } else {
        $title = get_the_title() . " $sep $title";
    }
    // Add a page number if necessary.
    if ($paged >= 2 || $page >= 2) {
        $title = sprintf(esc_html__('Page %s', 'kepler-wp'), max($paged, $page)) . " $sep $title";
    } // end if

    return esc_html($title);
}

add_filter('wp_title', 'kepler_custom_wp_title', 10, 2);


/*
 * conditional statement will show the featured content if at least there is one present
 * and while the page is not being paged (it is not in the second page onwards).
 */

function kepler_get_featured_content($num = 1) {
    global $featured;
    $featured = apply_filters('kepler_featured_content', array());

    if (is_array($featured) || $num >= count($featured))
        return true;

    return false;
}

// A helper conditional function that returns a boolean value.
function kepler_has_featured_posts() {
    return !is_paged() && (bool) kepler_get_featured_content();
}

// Pagination function
function kepler_pagination($pages = '', $range = 3) {
    $showitems = ($range * 2) + 1;
    //$showitems = $range-1;

    global $paged;
    if (empty($paged))
        $paged = 1;

    if ($pages == '') {
        global $wp_query;
        $pages = $wp_query->max_num_pages;
        if (!$pages) {
            $pages = 1;
        }
    }

    if (1 != $pages) {
        echo "<ul class=\"pagination\">";

        if ($paged > 2 && $paged > $range + 1 && $showitems < $pages) {
            echo "<li class=\"page-numbers prev\"><a  href='" . esc_url(get_pagenum_link(1)) . "' title='" . esc_html__('First page', 'kepler-wp') . "'>&lt;</a></li>";
        }

        for ($i = 1; $i <= $pages; $i++) {
            if (1 != $pages && (!($i >= $paged + $range + 1 || $i <= $paged - $range - 1) || $pages <= $showitems )) {
                echo ($paged == $i) ? "<li class=\"page-numbers nav-links current\"><a href='" . esc_url(get_pagenum_link($i)) . "'>" . esc_html($i) . "</a></li>" :
                        "<li class=\"page-numbers nav-links\"><a href='" . esc_url(get_pagenum_link($i)) . "'>" . esc_html($i) . "</a></li>";
            }
        }

        if ($paged < $pages - 1 && $paged + $range - 1 < $pages && $showitems < $pages) {
            echo "<li class=\"page-numbers next\"><a href='" . esc_url(get_pagenum_link($pages)) . "' title='" . esc_html__('Last page', 'kepler-wp') . "'>&gt;</a></li>";
        }

        echo "</ul>\n";
    }
}

function kepler_add_editor_styles() {
    add_editor_style('/assets/css/lists.css');
}

add_action('admin_init', 'kepler_add_editor_styles');

// Add Formats Dropdown Menu To MCE
if (!function_exists('kepler_style_select')) {

    function kepler_style_select($buttons) {
        array_push($buttons, 'styleselect');
        return $buttons;
    }

}

add_filter('mce_buttons', 'kepler_style_select');
// Add new styles to the TinyMCE "formats" menu dropdown
if (!function_exists('kepler_styles_dropdown')) {

    function kepler_styles_dropdown($settings) {

        // Create array of new styles
        $new_styles = array(
            array(
                'title' => esc_html__('List Styles', 'kepler-wp'),
                'items' => array(
                    array(
                        'title' => esc_html__('Check', 'kepler-wp'),
                        'selector' => 'ul',
                        'classes' => 'check'
                    )
                )
            )
        );

        // Merge old & new styles
        $settings['style_formats_merge'] = true;

        // Add new styles
        $settings['style_formats'] = json_encode($new_styles);

        // Return New Settings
        return $settings;
    }

}
add_filter('tiny_mce_before_init', 'kepler_styles_dropdown');

// Widget areas
function kepler_widgets_init() {
    // creates the default sidebar
    register_sidebar(array(
        'name' => esc_html__('Default Sidebar', 'kepler-wp'),
        'id' => 'kepler-default-sidebar',
        'description' => esc_html__('Default widget area', 'kepler-wp'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h4 class="widget-title">',
        'after_title' => '</h4>',
    ));

    // Generates the the top widget areas of the footer
    for ($count = 1; $count <= 4; $count++) {
        register_sidebar(array(
            'name' => esc_html__('Header Widget Area ', 'kepler-wp') . $count,
            'id' => 'kepler-footer-top-sidebar-' . $count,
            'description' => esc_html__('Widget area', 'kepler-wp'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h4 class="widget-title">',
            'after_title' => '</h4>',
        ));
    }

    // Generates the the middle widget areas of the footer
    for ($count = 1; $count <= 4; $count++) {
        register_sidebar(array(
            'name' => esc_html__('Footer Widget Area ', 'kepler-wp') . $count,
            'id' => 'kepler-footer-middle-sidebar-' . $count,
            'description' => esc_html__('Widget area', 'kepler-wp'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h4 class="widget-title">',
            'after_title' => '</h4>',
        ));
    }

    $option_name = 'kepler-sidebars-custom';
    if (get_option($option_name) != false) {

        $sidebars_array = get_option($option_name);
        if ($sidebars_array != null) {
            $count = count($sidebars_array);
            $j = 0;

            for ($i = 0; $i < $count; $i = $i + 2) {

                // Stores sidebars titles
                $sidebars_title[$j] = esc_html($sidebars_array[$i]);
                // Stores sidebars description
                $sidebars_description[$j] = esc_html($sidebars_array[$i + 1]);

                if (function_exists('register_sidebar')) {
                    // Registers each sidebar with title and description
                    register_sidebar(array(
                        'name' => $sidebars_title[$j],
                        'id' => sanitize_title_with_dashes($sidebars_title[$j]) . '-' . $j,
                        'description' => $sidebars_description[$j],
                        'before_widget' => '<div id="%1$s" class="widget %2$s">',
                        'after_widget' => '</div>',
                        'class' => 'kepler-sidebars-custom',
                        'before_title' => '<h4 class="widget-title">',
                        'after_title' => '</h4>',
                    ));
                }
                $j++;
            }
        }
    }
}

add_action('widgets_init', 'kepler_widgets_init');

function kepler_excerpt($more) {
    return '...';
}

add_filter('excerpt_more', 'kepler_excerpt');

if (defined('WPB_VC_VERSION')) {
    include_once(get_template_directory() . '/framework/composer/init.php');
}

include_once(get_template_directory() . '/framework/admin/theme_options.php');
include_once(get_template_directory() . '/framework/plugins/tgm-plugin-activation/class-tgm-plugin-activation.php');
include_once(get_template_directory() . '/framework/metaboxes.php');
include_once(get_template_directory() . '/framework/sidebar_ajax.php');
include_once(get_template_directory() . '/framework/widgets.php');

class kepler_Nav_Menu_Walker extends Walker_Nav_Menu {

    // Variables used to determine the first menu item
    public $kepler_mega_menu = 0;
    public $kepler_mega_section = 0;

    function display_element($element, &$children_elements, $max_depth, $depth = 0, $args, &$output) {
        $this->child_count = ( isset($children_elements[$element->ID]) ) ? count($children_elements[$element->ID]) : 0;
        $this->ID = $element->ID;
        $this->depth = $depth;
        $this->have_current = true;
        $mega_count = 0;

        if ($this->child_count > 0) {

            foreach ($children_elements[$element->ID] as $child) {
                if (isset($child->classes)) {
                    foreach ($child->classes as $class) {
                        if ($class == 'kepler-nav-mega-enabled') {
                            $mega_count++;
                        }
                    }
                }
            }
        }
        $element->classes[] = 'mega-section-count-' . $mega_count;
        parent::display_element($element, $children_elements, $max_depth, $depth, $args, $output);
    }

    public function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0) {
        $indent = ( $depth ) ? str_repeat("\t", $depth) : '';

        $classes = empty($item->classes) ? array() : (array) $item->classes;
        $check = $check2 = 0;
        foreach ($classes as $class_single) {
            if (trim($class_single) == 'menu-item-has-children') {
                $check = 1;
            }
            if (trim($class_single) == 'kepler-nav-mega-enabled') {
                $check2 = 1;
            }
        }
        $classes[] = 'menu-item-' . $item->ID;
        if ($check == 1 && $check2 == 0) {
            $classes[] = 'dropdown';
        }

        /**
         * Filter the CSS class(es) applied to a menu item's <li>.
         *
         * @since 3.0.0
         *
         * @see wp_nav_menu()
         *
         * @param array  $classes The CSS classes that are applied to the menu item's <li>.
         * @param object $item    The current menu item.
         * @param array  $args    An array of wp_nav_menu() arguments.
         */
        $class_names = join(' ', apply_filters('nav_menu_css_class', array_filter($classes), $item, $args));

        $class_parts = explode(' ', $class_names);

        $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

        $mega_count = 0;

        foreach ($class_parts as $class_part) {
            $mega_count_class = explode('mega-section-count-', $class_names);

            if (isset($mega_count_class[1])) {
                $mega_count = (int) $mega_count_class[1];
            }
        }

        /**
         * Filter the ID applied to a menu item's <li>.
         *
         * @since 3.0.1
         *
         * @see wp_nav_menu()
         *
         * @param string $menu_id The ID that is applied to the menu item's <li>.
         * @param object $item    The current menu item.
         * @param array  $args    An array of wp_nav_menu() arguments.
         */
        $id = apply_filters('nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args);
        $id = $id ? ' id="' . esc_attr($id) . '"' : '';

        $kepler_mega_menu_start = $kepler_mega_section_start = '';
        global $kepler_mega_section;
        global $kepler_mega_menu;


        if ($depth == 0) {

            foreach ($classes as $class) {
                if (trim($class) == "kepler-nav-mega-enabled") {
                    $mega_col = '';
                    if ($mega_count != 0) {
                        if ($mega_count >= 4) {
                            $mega_col = ' sf-mega-4-col';
                        } else {
                            $mega_col = ' sf-mega-' . $mega_count . '-col';
                        }
                    }

                    $kepler_mega_menu_start = '<div class="sf-mega' . $mega_col . '">';
                    $kepler_mega_menu = 1;
                }
            }
        }

        if ($depth == 1) {
            foreach ($classes as $class) {
                if (trim($class) == "kepler-nav-mega-enabled" && $kepler_mega_menu == 1) {
                    if ($kepler_mega_section == 1) {
                        $output .= '</ul></div>';
                    }
                    $kepler_mega_section_start = '<div class="sf-mega-section"><ul>';
                    $kepler_mega_section = 1;
                }
            }
        }

        if ($kepler_mega_section_start != '') {
            $output .= $kepler_mega_section_start;
        }
        $output .= $indent . '<li' . $id . $class_names . '>';

        $atts = array();
        $atts['title'] = !empty($item->attr_title) ? $item->attr_title : '';
        $atts['target'] = !empty($item->target) ? $item->target : '';
        $atts['rel'] = !empty($item->xfn) ? $item->xfn : '';
        $atts['href'] = !empty($item->url) ? $item->url : '';

        /**
         * Filter the HTML attributes applied to a menu item's <a>.
         *
         * @since 3.6.0
         *
         * @see wp_nav_menu()
         *
         * @param array $atts {
         *     The HTML attributes applied to the menu item's <a>, empty strings are ignored.
         *
         *     @type string $title  Title attribute.
         *     @type string $target Target attribute.
         *     @type string $rel    The rel attribute.
         *     @type string $href   The href attribute.
         * }
         * @param object $item The current menu item.
         * @param array  $args An array of wp_nav_menu() arguments.
         */
        $atts = apply_filters('nav_menu_link_attributes', $atts, $item, $args);

        $attributes = '';
        foreach ($atts as $attr => $value) {
            if (!empty($value)) {
                $value = ( 'href' === $attr ) ? esc_url($value) : esc_attr($value);
                $attributes .= ' ' . $attr . '="' . $value . '"';
            }
        }

        $item_output = $args->before;
        $item_output .= '<a' . $attributes . '>';
        /** This filter is documented in wp-includes/post-template.php */
        $item_output .= $args->link_before . apply_filters('the_title', $item->title, $item->ID) . $args->link_after;
        $item_output .= '</a>';
        if ($kepler_mega_menu_start != '') {
            $item_output .= $kepler_mega_menu_start;
        }
        $item_output .= $args->after;

        /**
         * Filter a menu item's starting output.
         *
         * The menu item's starting output only includes $args->before, the opening <a>,
         * the menu item's title, the closing </a>, and $args->after. Currently, there is
         * no filter for modifying the opening and closing <li> for a menu item.
         *
         * @since 3.0.0
         *
         * @see wp_nav_menu()
         *
         * @param string $item_output The menu item's starting HTML output.
         * @param object $item        Menu item data object.
         * @param int    $depth       Depth of menu item. Used for padding.
         * @param array  $args        An array of wp_nav_menu() arguments.
         */
        $output .= apply_filters('walker_nav_menu_start_el', $item_output, $item, $depth, $args);
    }

    function end_lvl(&$output, $depth = 0, $args = array()) {
        $indent = str_repeat("\t", $depth);
        global $kepler_mega_section;
        global $kepler_mega_menu;
        if ($kepler_mega_section == 1) {
            $output .= '</ul></div></div>';
            $kepler_mega_section = 0;
            $output .= "$indent\n";
            $kepler_mega_menu = 0;
        } else {
            $output .= "$indent</ul>\n";
        }
    }

    function start_lvl(&$output, $depth = 0, $args = array()) {
        $indent = str_repeat("\t", $depth);
        global $kepler_mega_menu;
        if ($kepler_mega_menu == 1) {
            $output .= "\n$indent\n";
        } else {
            $output .= "\n$indent<ul class=\"sub-menu\">\n";
        }
    }

}

add_filter('the_content_more_link', 'kepler_read_more_link');

function kepler_read_more_link() {
    return '<p><a class="more-link btn" href="' . get_permalink() . '">' . esc_html__('Read More', 'kepler-wp') . '</a></p>';
}

add_filter('body_class', 'kepler_body_classes');

function kepler_body_classes($classes) {

    global $kepler_theme_options;

    if (isset($kepler_theme_options['kepler-boxed-switch'])) {
        if ($kepler_theme_options['kepler-boxed-switch'] == 1) {
            $classes[] = ' boxed';
        }
    }

    return $classes;
}

function kepler_options_var($type) {
    global $kepler_theme_options;
    if (isset($kepler_theme_options[$type])) {
        return $kepler_theme_options[$type];
    } else {
        return '';
    }
}

function kepler_pages_list() {
    $page_ids = get_all_page_ids();
    $pages_array = array();
    $pages_array['default'] = 'Default';
    foreach ($page_ids as $page_id) {
        // do not include the Auto Draft pages
        if (get_the_title($page_id) != 'Auto Draft') {
            $pages_array[$page_id] = esc_html(get_the_title($page_id));
        }
    }
    return $pages_array;
}
