<?php
/**
 * The Header template for kepler theme
 */
if (!defined('ABSPATH')) {
    exit();
}
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js">
    <head>
        <meta charset="<?php echo esc_attr(bloginfo('charset')); ?>">
        <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=0"/> 

        <meta name="msapplication-TileColor" content="<?php
        if (kepler_options_var('kepler-color-android-theme') != '') {
            echo kepler_options_var('kepler-color-android-theme');
        } else {
            echo '#000';
        }
        ?>">
        <meta name="theme-color" content="<?php
        if (kepler_options_var('kepler-ms-color') != '') {
            echo kepler_options_var('kepler-ms-color');
        } else {
            echo '#000';
        }
        ?>">

        <?php wp_head(); ?>
    </head>

    <body <?php body_class(); ?>>
        <?php
        if (is_page() || get_post_type() == 'erp-portfolio' && !is_search()) {
            $post_id = get_queried_object_id();
        } else {
            $post_id = get_option('page_for_posts');
        }

        $header_text = $image_header = $font_color = $header_parallax = '';

        if (class_exists('woocommerce')) {

            if (is_singular('product')) {
                $post_id = get_the_id();
            } else if (is_shop() || get_post_type() == 'product') {
                $post_id = get_option('woocommerce_shop_page_id');
            }
        }

        if (is_search()) {
            $header_text = sprintf(esc_html__('The search for %s returned:', 'kepler-wp'), get_search_query());
            $page_header_toggle = 'Enable';
            $image_header[0] = '';
        } else {

            $page_header_toggle = get_post_meta($post_id, 'kepler_header_toggle', true);
            if ($page_header_toggle == null) {
                update_post_meta($post_id, 'kepler_header_toggle', 'Enable');
                update_post_meta($post_id, 'kepler_header_title', get_the_title($post_id));
                $page_header_toggle = 'Enable';
            }

            if ($page_header_toggle == 'Enable') {
                $header_text = get_post_meta($post_id, 'kepler_header_title', true);
                if ($header_text == null && is_front_page()) {
                    $header_text = esc_html__('Home', 'kepler-wp');
                }
                $font_color = get_post_meta($post_id, 'kepler_header_font_color', true);
                $header_image_id = get_post_meta($post_id, 'kepler_header_image', true);
                if ($header_image_id == null) {
                    if (kepler_options_var('kepler-header-bg') != '') {
                        $img_header=kepler_options_var('kepler-header-bg');
                        $image_header[0] = $img_header['url'];
                    }
                    if ($image_header == null) {
                        $image_header = get_template_directory_uri() . '/assets/images/page-header-default.jpg';
                    }
                } else {
                    $image_header = wp_get_attachment_image_src($header_image_id, 'full');
                }
            }
        }
        ?>  

        <div id="wrap">

            <div id="header-wrap">
                <?php
                $kepler_footer_top_layout = kepler_options_var('kepler-footer-top-layout');
                if (kepler_options_var('kepler-footer-top-switch') == 1):
                    ?>
                    <div id="header-top">
                        <div class="container">
                            <div class="row">

                                <?php
                                // Sets widget area classes for top footer
                                $top_layout_class = "span3";

                                if ($kepler_footer_top_layout == 3) {
                                    $top_layout_class = "span4";
                                } elseif ($kepler_footer_top_layout == 2) {
                                    $top_layout_class = "span6";
                                } elseif ($kepler_footer_top_layout == 1) {
                                    $top_layout_class = "span12";
                                }
                                // 1 widget area for top footer
                                $count = 1;
                                for ($count; $count <= $kepler_footer_top_layout; $count++) {
                                    ?>
                                    <div class="<?php echo esc_attr($top_layout_class); ?>">

                                        <?php
                                        if (function_exists('dynamic_sidebar')) {

                                            if (is_active_sidebar('kepler-footer-top-sidebar-' . $count)) {
                                                dynamic_sidebar('kepler-footer-top-sidebar-' . $count);
                                            } else {
                                                ?>
                                                <div class="kepler-no-area-content"><?php echo esc_html__('Header Widget Area ', 'kepler-wp') . esc_html($count); ?></div>
                                                <?php
                                            }
                                        }
                                        ?>

                                    </div>
                                <?php }
                                ?>

                            </div>
                        </div>
                    </div>
                <?php endif; ?>

                <div id="header"<?php
                if ($page_header_toggle == 'Disable') {
                    echo ' class="kepler-no-border"';
                }
                ?>>                        

                    <!-- /// HEADER  //////////////////////////////////////////////////////////////////////////////////////////////////////////// -->

                    <div class="container">
                        <div class="row">
                            <div class="span3">

                                <!-- // Logo // -->
                                <div id="logo">
                                    <a href="<?php echo esc_url(home_url('/')); ?>">
                                        <img src="<?php
                                        if (kepler_options_var('kepler-header-logo') != '') {
                                            $logo=kepler_options_var('kepler-header-logo');
                                            echo esc_url($logo['url']);
                                        } else {
                                            echo esc_url(get_template_directory_uri() . '/assets/images/logo.png');
                                        }
                                        ?>" alt="website logo">
                                    </a>
                                </div>

                            </div><!-- end .span3 -->
                            <div class="span9">

                                <!-- // Mobile menu trigger // -->

                                <a href="#" id="mobile-menu-trigger">
                                    <i class="fa fa-bars"></i>
                                </a>

                                <!-- // Menu // -->
                                <nav>
                                    <?php
                                    // Wordpress navigation menu
                                    if (has_nav_menu('kepler-main-nav-menu')) {
                                        wp_nav_menu(array(
                                            'theme_location' => 'kepler-main-nav-menu',
                                            'container' => false,
                                            'fallback_cb' => false,
                                            'items_wrap' => '<ul id="menu" class="sf-menu fixed">%3$s</ul>',
                                            'walker' => new kepler_Nav_Menu_Walker())
                                        );
                                    } else {
                                        ?>
                                        <ul id="menu" class="sf-menu fixed"><li><a class="kepler-no-menu" href="<?php echo esc_url(admin_url('nav-menus.php')); ?>"><p><?php echo esc_html__('Please select a menu from Appearence > Menus', 'kepler-wp'); ?></p></a></li></ul>
                                    <?php } ?>
                                </nav>	

                            </div><!-- end .span9 -->
                        </div><!-- end .row -->		
                    </div><!-- end .container -->

                    <!-- //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////// -->

                </div><!-- end #header -->
            </div><!-- end #header-wrap -->	
            <div id="content">
                <?php if ($page_header_toggle == 'Enable') : ?>
                    <div id="page-header"<?php
                    if (trim($image_header[0]) != '') {
                        echo ' style="background-image:url(' . esc_url($image_header[0]) . ');"';
                    }
                    ?>>
                        <div class="container">
                            <div class="row">
                                <div class="span12">

                                    <?php if (trim($header_text) != '') { ?>
                                        <h6 class="page-header-title"<?php if (trim($font_color) != '') echo ' style="color:' . esc_attr($font_color) . ';"'; ?>><?php echo esc_html($header_text); ?></h6>
                                    <?php } ?>

                                </div><!-- end .span12 -->
                            </div><!-- end .row -->
                        </div><!-- end .container -->
                    </div><!-- end #page-header -->
                <?php endif; ?>